# Data documentation

#' @title Glossary
#' @description List of key words, their definition and a detailed description.
#' @format A data frame with 3 rows and 4 variables:
#' \describe{
#'   \item{\code{motclef}}{character The keyword.}
#'   \item{\code{definition}}{character Definition of the keyword.}
#'   \item{\code{descriptif}}{character Detailed description of the keyword.}
#'   \item{\code{alphabet}}{character First letter of the keyword.}
#'}
"glossaire"

#' Administrative limits of Centre-Val de Loire
#'
#' A simple feature geometry (cf. \code{\link[sf]{st_read}}) with the
#'     administrative limits of the French region Centre-Val de Loire (NUTS 2).
#'
#' @format A data frame with 1 feature and 5 fields:
#' \describe{
#'   \item{NOM_REGION}{Name of the region, NUTS 2}
#'   \item{code_supra}{French identification code for the region, NUTS 2}
#'   \item{NOUVEAUNOM}{New name of the region, NUTS 2}
#'   \item{geometry}{X and Y coordinates of polygons}
#'   \item{IDENTIFIANT}{Name of the region}
#'}
#' @source Raw data were provided by the National Institute of Geographic and Forest Information (IGN)
#' @source Data available at: \url{https://www.data.gouv.fr/fr/datasets/geofla-r/}
"regCVL"

#' Administrative limits of Cher, Eure-et-Loir, Indre, Indre-et-Loire, Loir-et-Cher et Loiret
#'
#' A simple feature geometry (\code{\link[sf]{st_read}}) with NUTS 3
#'     administrative limits for the 6 departments in the French region
#'     Centre-Val de Loire (NUTS 2).
#'
#' @format A data frame with 6 features and 10 fields:
#' \describe{
#'   \item{ID}{The IGN idenfication code}
#'   \item{NOM_DEP}{Name of the department, NUTS 3}
#'   \item{NOM_DEP_M}{Name of the department in capital letters, NUTS 3}
#'   \item{INSEE_DEP}{French identification code for the department, NUTS 3}
#'   \item{INSEE_REG}{French identification code for the region, NUTS 2}
#'   \item{CHF_DEP}{French identification code for the administrative center}
#'   \item{area}{Surface area in square meter}
#'   \item{area_km2}{Surface area in square kilometer}
#'   \item{geometry}{X and Y coordinates of polygons}
#'   \item{IDENTIFIANT}{Name of the department}
#'}
#' @source Raw data were provided by the National Institute of Geographic and Forest Information (IGN)
#' @source Data available at: \url{https://geoservices.ign.fr/documentation/diffusion/telechargement-donnees-libres.html#admin-express}
"depCVL"

#' Administrative limits of roe deer hunting management units in Centre-Val de Loire
#'
#' A simple feature geometry (\code{\link[sf]{st_read}}) with the
#'     administrative limits for the roe deer hunting management units in
#'     Centre-Val de Loire (NUTS 2).
#'
#' @format A data frame with 371 features and 10 fields:
#' \describe{
#'   \item{PERIMETER}{The perimeter of the management unit, m}
#'   \item{NOM_DEPT}{Name of the department, NUTS 3}
#'   \item{CODE_DEPT}{French identification code for the department, NUTS 3}
#'   \item{USC1}{The interal identification code used by INRAE}
#'   \item{ID}{The idenfication code given by the FDC}
#'   \item{CERF}{Identification code of the red deer management unit given by the FDC}
#'   \item{LIBELLE}{Label of the management unit given by the FDC, if any}
#'   \item{AREA_HA}{Surface area, ha}
#'   \item{geometry}{X and Y coordinates of polygons}
#'   \item{UG}{Identification code of the management unit, DEP-FDC ID}
#'   \item{IDENTIFIANT}{Idenification code of the managemen tunit, DEP-INRAE ID}
#'}
#' @source Raw data were provided by the Fédération Régionale des Chasseurs du Centre-Val de Loire
"usc"

#' Centroids of roe deer hunting management units in Centre-Val de Loire
#'
#' A simple feature geometry (\code{\link[sf]{st_read}}) with the
#'     centroids for the roe deer hunting management units in
#'     Centre-Val de Loire (NUTS 2).
#'
#' @format A data frame with 371 features and 12 fields:
#' \describe{
#'   \item{PERIMETER}{The perimeter of the management unit, m}
#'   \item{NOM_DEPT}{Name of the department, NUTS 3}
#'   \item{CODE_DEPT}{French identification code for the department, NUTS 3}
#'   \item{USC1}{The interal identification code used by INRAE}
#'   \item{ID}{The idenfication code given by the FDC}
#'   \item{CERF}{Identification code of the red deer management unit given by the FDC}
#'   \item{LIBELLE}{Label of the management unit given by the FDC, if any}
#'   \item{AREA_HA}{Surface area, ha}
#'   \item{X_L93}{X coordinates in RGF93 Lambert 93}
#'   \item{Y_L93}{Y coordinates in RGF93 Lambert 93}
#'   \item{geometry}{X and Y coordinates of polygons}
#'   \item{UG}{Identification code of the management unit, DEP-FDC ID}
#'   \item{IDENTIFIANT}{Idenification code of the managemen tunit, DEP-INRAE ID}
#'}
#' @source Raw data were provided by the Fédération Régionale des Chasseurs du Centre-Val de Loire
"usc_centroids"

