#### Fichier serveur de l'application ReForest ####

### INRAE : Projet ReForest : Création d'un démonstrateur
### Auteur : DUMBO Marie
### Date : 10/06/2020
### Mise-à-jours : cf. Git history for successive modifications by MÅRELL Anders

#---------- Environnement de travail ----------

# Répertoire de travail
pathModule <- paste(getwd(),'modules', sep = "/")
l.module <- list.files(pathModule, full.names = TRUE)

# Dépendances
library(shiny)
library(ClustOfVar) # Classification
library(zoo) # dependency for strucchange
library(sandwich) # dependency for strucchange
library(strucchange) # trend analysis
library(gridExtra) # Téléchargement
library(rmarkdown) # Création de rapport Rmarkdown
library(sf) # traitement des données spatialisées
library(leaflet) # cartes interactives

for (i in l.module){source(i, encoding = 'UTF-8')}


#---------- Script ----------

#------ UI ------

ui <- navbarPage(windowTitle = "tdbesc - ReForest",
                 title =
                   div(id = "logo",
                       img(src = "Logo_esc_rond_fond_gris_transp_48px.png",
                           height = "24px"),
                       "Tableau de bord ReForest"),
                 position = "static-top",
                 id = "navbar",
                 header = tags$head(
                   # div(class = "my_header",
                   #     style = "background-color: #66c1bf;
                   #      font-size: 24px;
                   #      font-weight: bold;
                   #      color: white",
                   #     img(src = "Logo_esc_rond_fond_gris_transp_48px.png",
                   #         style = "padding-left:5px;
                   #         padding-right:5px;
                   #         padding-bottom:5px;
                   #         padding-top:5px"),
                   #     "Tableau de bord ReForest"),
                   tags$link(rel = "stylesheet",
                             type = "text/css",
                             href = "style.css")
                 ),
                 footer = column(12,
                                 tags$hr(class = "hr_thick"),
                                 column(3, align = "left",
                                        tags$p(class = "footer",
                                               "Développé par Anders Mårell et
                                               Marie Dumbo")),
                                 column(6, tags$div(class = "footer",
                                          img(src="Bandeau_logos_edited.jpg",
                                              width = "100%"))),
                                 column(3, align = "right",
                                        tags$p(class = "footer",
                                               "Version 1.0.0"))),

                 tabPanel("Acceuil",
                          sidebarLayout(
                            mainPanel(
                              tags$h1(
                                "Bienvenue sur le tableau de bord ReForest ! "),
                              tags$h2("C'est votre première visite ?"),
                              tags$p("N'hésitez pas à visionner le tutoriel
                                     et à parcourir la documentation que vous
                                     trouverez dans la barre de menu en haut."),
                              tags$br(),
                              tags$video(src = "video.mp4",
                                         controls = "controls",
                                         width = "468px"),
                            width = 9),
                            navigDocuUI("sb_acc"))
                 ),

                 tabPanel("Visualisation",
                          tags$h1("Visualisation des données "),
                          # tags$br(),
                          fluidRow(
                            column(width = 3,
                                   sidebarUI("visu")
                            ),
                            column(width = 9,
                                   plotExportUI("export")
                            )
                          )
                 ),

                 tabPanel("Cartographie",
                          tags$h1("Cartographie interactive"),
                          # tags$br(),
                          fluidRow(
                            column(width = 3,
                              sidebarUI("carto")
                            ),
                            column(width = 6,
                              mapExportUI("mapexport")
                            ),
                            column(width = 3,
                              sidebarUI2("carto")
                            )
                          )
                 ),

                 tabPanel("Echantillonnage",
                          tags$h1(
                            "Plan d'échantillonnage"),
                          tags$br(),
                          tags$h2("Ici, nous vous proposerons dans la prochaine
                                  mise à jour de l'application des
                                  fonctionnalités pour effectuer un plan
                                  d'échantillonnage. Vous aurez la possibilité
                                  des sélectionner des peuplements forestiers à
                                  visiter dans le cadre des expertises, des
                                  inventaires ou des diagnostics sylvicoles
                                  conjoints.")
                 ),

                 navbarMenu("Analyses",
                            tabPanel("Classification",
                                     tags$h1(
                                       "Classification des unités de gestion"),
                                     tags$br(),
                                     tags$h2(
                                       "L'onglet de classification hiérarchique
                                       est actuellement sous révision à cause
                                       de nombreuses modifications dans la
                                       structure des données. Il sera
                                       disponible dans la prochaine mise
                                       à jour de l'application."
                                     )
                            ),

                            # tabPanel("Classification",
                            #          tags$h1(
                            #            "Classification des unités de gestion"),
                            #          tags$br(),
                            #          sidebarLayout(
                            #            sidebarUI("classif"),
                            #            clusteringUI("res.classif")
                            #          )
                            # ),

                            tabPanel("Analyse des tendances",
                                     tags$h1(
                                       "Analyse des tendances d'ICE"),
                                     tags$br(),
                                     sidebarLayout(
                                       sidebarUI("tendance"),
                                       trendUI("tendance.visu")
                                     )
                            ),

                            tabPanel("Analyse des risques",
                                     tags$h1(
                                       "Analyse des risques"),
                                     tags$br(),
                                     sidebarLayout(
                                       sidebarUI("risque"),
                                       mainPanel("CONTENU")
                                     ))),

                 tabPanel("Rapport synthétique",
                          tags$h1(
                            "Rapport synthétique"),
                          tags$br(),
                          sidebarUI("rapport"),
                          reportUI("export.rapport")
                 ),

                 navbarMenu("Documentation",
                            tabPanel(title = "Mode d'emploi", value = "tbd",
                                     sidebarLayout(
                                       mainPanel( tbdUI(), width = 9 ),
                                       navigDocuUI("sb_tbd")
                                     )
                            ),
                            tabPanel(title = "Projet ReForest",
                                     value = "projet",
                                     sidebarLayout(
                                       mainPanel( projetUI(), width = 9 ),
                                       navigDocuUI("sb_projet")
                                     )
                            ),
                            tabPanel(title = "Equilibre sylvo-cynégétique",
                                     value = "equilibre",
                                     sidebarLayout(
                                       mainPanel( equilibreUI(), width = 9),
                                       navigDocuUI("sb_equilibre")
                                     )
                            ),
                            tabPanel(title = "Gestion adaptative",
                                     value = "gestion",
                                     sidebarLayout(
                                       mainPanel( gestionUI(), width = 9),
                                       navigDocuUI("sb_gestion")
                                     )
                            ),
                            tabPanel(title = "Glossaire",
                                     value = "glossaire",
                                     sidebarLayout(
                                       mainPanel(glossaireUI(), widht = 9),
                                       navigDocuUI("sb_glossaire")
                                     )
                            )
                 )
)

#------ SERVER ------

server <- function(input, output, session)
{
  # Modules pour les 'sidebars' #####
  callModule(navigDocu,"sb_acc", parent_session = session)
  callModule(navigDocu,"sb_tbd", parent_session = session)
  callModule(navigDocu,"sb_projet", parent_session = session)
  callModule(navigDocu,"sb_equilibre", parent_session = session)
  callModule(navigDocu,"sb_gestion", parent_session = session)
  callModule(navigDocu,"sb_glossaire", parent_session = session)

  # Modules pour l'onglet 'Visualisation' #####
  dataset.visu <- callModule(selectDataset, "visu")
  indicateur.visu <- callModule(selectIndicateur,"visu",
                                dataset.visu, parent_session = session)
  callModule(selectLocation, "visu", dataset.visu)
  callModule(selectYear,"visu", parent_session = session,
             dataset.visu, indicateur.visu)
  callModule(selectIndiv,"visu", indicateur.visu)

  parametre.visu1 <- callModule(buttonGraph1, "visu")
  data.graph1 <- callModule(graphic,"visu.plot1",
                            reactive(parametre.visu1$donnees),
                            reactive(parametre.visu1$indicateur),
                            reactive(parametre.visu1$echelle),
                            reactive(parametre.visu1$lieu),
                            reactive(parametre.visu1$individu),
                            reactive(parametre.visu1$annee))

  parametre.visu2 <- callModule(buttonGraph2, "visu")
  data.graph2 <- callModule(graphic,"visu.plot2",
                            reactive(parametre.visu2$donnees),
                            reactive(parametre.visu2$indicateur),
                            reactive(parametre.visu2$echelle),
                            reactive(parametre.visu2$lieu),
                            reactive(parametre.visu2$individu),
                            reactive(parametre.visu2$annee))

  parametre.visu3 <- callModule(buttonGraph3, "visu")
  data.graph3 <- callModule(graphic,"visu.plot3",
                            reactive(parametre.visu3$donnees),
                            reactive(parametre.visu3$indicateur),
                            reactive(parametre.visu3$echelle),
                            reactive(parametre.visu3$lieu),
                            reactive(parametre.visu3$individu),
                            reactive(parametre.visu3$annee))

  parametre.visu4 <- callModule(buttonGraph4, "visu")
  data.graph4 <- callModule(graphic,"visu.plot4",
                            reactive(parametre.visu4$donnees),
                            reactive(parametre.visu4$indicateur),
                            reactive(parametre.visu4$echelle),
                            reactive(parametre.visu4$lieu),
                            reactive(parametre.visu4$individu),
                            reactive(parametre.visu4$annee))

  callModule(plotExport,
             "export",
             data.graph1,
             data.graph2,
             data.graph3,
             data.graph4)


  # Modules pour l'onglet 'Cartographie' #####
  dataset.carto <- callModule(selectDataset, "carto")
  # norme.carto <- callModule(selectTypeIndicateur, "carto")
  indicateur.carto <- callModule(selectIndicateur, "carto",
                                 dataset.carto, parent_session = session)
  callModule(selectLocation, "carto", dataset.carto)
  callModule(selectYear,"carto", parent_session = session,
             dataset.carto, indicateur.carto)
  callModule(selectIndiv,"carto", indicateur.carto)
  callModule(selectTableau, "carto",
             dataset.carto, indicateur.carto)
#  tableau.carto <- callModule(selectedTableau, "carto")

  parametre.carte <- callModule(buttonCarte, "carto")
  data.carte <- callModule(carteinteractive, "carto.map",
                           reactive(parametre.carte$donnees),
                           reactive(parametre.carte$tableau),
                           reactive(parametre.carte$indicateurgeo),
                           reactive(parametre.carte$cible),
                           reactive(parametre.carte$indicateur),
                           reactive(parametre.carte$individu),
                           reactive(parametre.carte$annee),
                           reactive(parametre.carte$echelle))
  callModule(mapExport, "mapexport", data.carte, parametre.carte)

  # Modules pour la classification hiérarchique #####
  # dataset.classif <- callModule(selectDataset, "classif")
  # callModule(selectYear, "classif")
  # callModule(enterCluster, "classif", data = dataset.classif)
  # parametre.classif <-  callModule(buttonClassif, 'classif')
  # callModule(clustering, "res.classif",
  #            reactive(parametre.classif$donnee),
  #            reactive(parametre.classif$annee),
  #            reactive(parametre.classif$k))


  # Modules pour l'analyse des tendances #####
  emplacement.tendance <- callModule(selectLocation, "tendance")
  incateur.tendance <- callModule(selectIndicateur, "tendance",
                                  lieu = reactive(emplacement.tendance$lieu))
  indiv.tendance <- callModule(selectIndiv,"tendance", incateur.tendance)
  parametre.tendance <- callModule(buttonLauch,"tendance")
  callModule(trend, "tendance.visu",
             reactive(parametre.tendance$indicateur),
             reactive(parametre.tendance$lieu),
             reactive(parametre.tendance$individu))

  # Modules pour le rapport synthétique #####
  data.rapport <- callModule(selectDataset, 'rapport')
  lieu.rapport <- callModule(selectLocation, "rapport" )
  indiv.rapport <- callModule(selectIndiv,"rapport")
  callModule(report, 'export.rapport',
             reactive(data.rapport()),
             reactive(lieu.rapport$echelle),
             reactive(lieu.rapport$lieu),
             reactive(indiv.rapport()))

}


#------ LANCEMENT ------

shinyApp(ui = ui, server = server)
