#### MODULE CREANT LES PAGES D'ACCEUIL ####
#### ET DE DOCUMENTATION DE L'APPLICATION REFOREST ####

### INRAE : Projet ReForest : Création d'un démonstrateur
### Auteur : DUMBO Marie
### Date : 22/06/2020
### Mise-à-jours : cf. Git history for successive modifications by MÅRELL Anders

#---------- Menu de selection de la documentation ----------

navigDocuUI <- function(id){
  ns <- NS(id)
  tagList(
    sidebarPanel(
      tags$h2("Pour en savoir plus"), tags$br(),
      tags$div(
               actionButton(ns("bt_tbd"),
                            label = "Tableau de bord - Mode d'emploi"),
               tags$br(), tags$br(),
               actionButton(ns("bt_projet"),
                            label = "Projet ReForest"),
               tags$br(),tags$br(),
               actionButton(ns("bt_equilibre"),
                            label = "Equilibre sylvo-cynégétique"),
               tags$br(),tags$br(),
               actionButton(ns("bt_gestion"),
                            label = "Gestion adaptative"))
    , width = 3)
  )
}

navigDocu <- function(input, output, session, parent_session){
  observeEvent(input$bt_tbd, {
    updateNavbarPage(session=parent_session,
                     inputId = "navbar",
                     selected = "tbd")
  })
  observeEvent(input$bt_projet, {
    updateNavbarPage(session=parent_session,
                     inputId = "navbar",
                     selected = "projet")
  })
  observeEvent(input$bt_equilibre, {
    updateNavbarPage(session=parent_session,
                     inputId = "navbar",
                     selected = "equilibre")
  })
  observeEvent(input$bt_gestion, {
    updateNavbarPage(session=parent_session,
                     inputId = "navbar",
                     selected = "gestion")
  })
}

#---------- Contenue de la documentation ----------

tbdUI <- function(){
  tagList(
    tags$h1("Le Tableau de bord ReForest :"),
    tags$p("Le tableau de bord ReForest est un outil d'aide à la gestion
          adaptative de l'équilibre forêt-cervidés au travers de l'analyse
          d'indicateurs sylvicoles et cynégétiques. Ce tableau de bord a été
          conçu dans le cadre du projet ReForest qui associe dans une démarche
          participative les gestionnaires de la forêt, les gestionnaires de la
          faune sauvage, des représentants de l'état et des scientifiques de
          l'INRAE de la région Centre Val-de Loire.", align="justify"),
    tags$p("Le tableau de bord ReForest a pour principal objectif la
          visualisation et l'analyse de données afin de faciliter des
          différents acteurs dans leurs prises de décisions en termes de
          gestion sylvicole et cynégétique. Cette interface offre la
          possibilité de sauvegarder le résultat des requêtes formulées par le
          téléchargement de fichiers numériques au format PDF. Ce tableau de
          bord a également pour vocation d'informer sur l'avancement du projet
          ReForest et de documenter sur la thématique de l'équilibre
          forêt-cervidés.", align="justify"),
    tags$p("Au niveau de la barre de menu principal, cinq onglets permettent
          d'accéder aux fonctionnalités du tableau de bord :", align="justify"),
    tags$ul(list(
      tags$li("L'onglet ", tags$a(href = "#Visualisation des données",
              tags$strong("'Visualisation'"))," est dédié à la
              représentation graphique des indicateurs référencés dans la
              plateforme ;"
              , align="justify"),
      tags$li("L'onglet ", tags$a(href = "#Cartographie",
              tags$strong("'Cartographie'"))," est dédié à la
              représentation cartographique des indicateurs référencés dans la
              plateforme ;"
              , align="justify"),
      tags$li("L'onglet ", tags$a(href = "#Analyses",
              tags$strong("'Analyses'"))," permet d'interpréter des
              données issues d'observations ou résultant des indicateurs mis en
              œuvre ;"
              , align="justify"),
      tags$li("L'onglet ", tags$a(href = "#Rapports synthétiques",
              tags$strong("'Rapports synthétiques'"))," a pour
              finalité de sélectionner les paramètres d'export des résultats
              que l'on souhaite télécharger (en cours d'implémentation) ;"
              , align="justify"),
      tags$li("L'onglet ", tags$a(href = "#Documentation",
              tags$strong("'Documentation'"))," ouvre l'accès à la
              consultation de cinq rubriques informatives. A noter que ces
              rubriques sont également consultables depuis la page « Accueil »
              en dessous de la mention «Pour en savoir plus »."
              , align="justify")
    )),
    tags$p("Le prototype actuel contient des données sylvicoles et cynégétiques,
           mais permettra à terme d'intégrer d'autres types de données et
           indicateurs (selon leur disponibilité), par exemple dans les
           thématiques agricoles, de santé humaine et de biodiversité.",
           align="justify"),
    tags$br(), tags$hr(), tags$br(),
    tags$h2("Mode d'emploi"),
    tags$h3(tags$a(id = "Visualisation des données",
                   "Visualisation des données" )),
    tags$p("Dans l'onglet 'Visualisation' du tableau de bord ReForest, vous
          pouvez visualiser les données sylvo-cynégétiques disponibles. Cette
          visualisation se fait de manière interactive et vous permet d'avoir
          une vue d'ensemble sur la situation sylvo-cynégétique en Centre-Val
          de Loire. Sont proposées des représentations cartographiques et des
          évolutions temporelles sous forme de graphiques."),
    tags$p("L'onglet 'Visulaisation' fonctionne de manière intuitive par
          sélection des paramètres proposés pour chacune des rubriques
          affichées (menus déroulants). Il est possible de créer jusqu'à quatre
          requêtes dont l'affichage s'opère par leur affection à l'un des
          quatre espaces réservés à cet effet. Le choix de l'espace d'affichage
          se fait par l'intermédiaire de quatre boutons. Ce choix peut à tout
          moment être modifié en réinitialisant le bouton de l'espace concerné.
          Cette option permet d'ordonner les graphiques à votre convenance."),
    tags$p("L'application permet de saisir un commentaire (facultatif) afin de
           préciser l'objet de votre requête. Il ne reste plus, à ce stade,
           qu'à sauvegarder votre requête en utilisant le bouton
           'Téléchargement'."),
    tags$p("Pour plus d'informations, regardez le tutoriel ci-dessous :"),
    tags$video(src = "visualisation.mp4",
               controls = "controls",
               width = "468px"),
    tags$br(), tags$hr(), tags$br(),
    tags$h3(tags$a(id = "Cartographie",
                   "Cartographie")),
    tags$p("TEXTE A REDIGER"),
    tags$br(), tags$hr(), tags$br(),
    tags$h3(tags$a(id = "Analyses", "Analyses")),
    tags$br(), tags$hr(), tags$br(),
    tags$h4("Classification des unités de gestion"),
    tags$p(" La classification des unités de gestion est une analyse permettant
          de les regrouper selon des critères de ressemblance. Cela facilite
          une perception globale de l'état sylvo-cynégétique des unités de
          gestion du Centre-val de Loire."),
    tags$p("Cette analyse se réalise de manière assez intuitive en paramétrant
           le type de données, la période d'analyse et le nombre de classes
           souhaitées dans le menu de sélection."),
    tags$p("Les résultats sont visualisables sous trois formats :"),
    tags$ul(list(
      tags$li("La forme cartographique présente les résultats pour l'ensemble
              des 374 unités de gestion de la région Centre-Val de Loire. Elle
              permet, ainsi, de spatialiser les zones de ressemblances ou
              l'hétérogénéités ;"),
      tags$li("Le tableau de résultats donne la composition de chacune des
              classes en termes d'unités de gestion. Elles sont référencées de
              la manière suivante : Numéro du département suivi du numéro
              d'ordre de l'unité dans le département. Vous pouvez aussi
              retrouver facilement une unité de gestion (notamment avec
              Ctrl+F) ;"),
      tags$li("Les résultats graphiques facilitent l'interprétation de la
              classification. Ils visualisent les caractéristiques d'une classe
              spécifique (à sélectionner) par rapport à la distribution des
              valeurs observées pour chacune des variables mobilisées pour la
              construction de l'analyse. Cela illustre les valeurs des variables
              qui ont contribué aux caractéristiques de la classe étudiée.")
    )),
    tags$p("Après avoir ajouté un commentaire (facultatif), la sauvegarde de
           l'analyse se fait pas l'intermédiaire du bouton 'Téléchargement'."),
    tags$div(img(src="boxplot.png")),
    tags$p(" Pour plus d'informations sur la manière dont l'analyse doit être
           lancée, n'hésitez pas à visualiser cette vidéo :"),
    tags$video(src = "classification.mp4",
               controls = "controls",
               width = "468px"),
    tags$b(),
    tags$p("D'un point de vue technique, la composition des classes est
          réalisée à l'aide de la méthode des Kmeans grâce au package R
          'ClustOfVar' (Chavent et al. 2017). Elle est paramétrée avec 9
          partitions initiales et le nombre de classes par défaut est celui
          donnant la meilleur homogénéité des classes. On note que pour cette
          analyse, des variables ont dû être retirées :"),
    tags$ul(list(
      tags$li("Les données sylvicoles 'Gibier' du CRPF, parce qu'elles
              comportaient trop de données manquantes"),
      tags$li("Les données corrélées à plus de 80 %, pour des questions
              d'optimisation de modèle. Cela concerne 6 variables du plan de
              chasse et 9 variables cynégétiques")
    )),
    tags$p(tags$u(tags$strong("Liste de références :"))),
    tags$ul(list(
      tags$li("Chavent, M., Kuentz, V., Liquet, B., Saracco, J. 2017.
              ClustOfVar: Clustering of Variables. R package version 1.1.",
              tags$a(href = "https://CRAN.R-project.org/package=ClustOfVar",
                     "https://CRAN.R-project.org/package=ClustOfVar"))
    )),
    tags$br(), tags$hr(), tags$br(),
    tags$h4("Analyse des tendances des ICE"),
    tags$p("L'analyse des tendances d'ICE caractérise de manière temporelle
          L'évolution des ICE à l'échelle des unités de gestion. Elle permet
          d'identifier des périodes sur lesquelles l'indicateur évolue à la
          hausse, à la baisse ou se stabilise. L'analyse des tendances d'ICE
          permet de comprendre l'état de l'équilibre sylvo-cynégétique, comme
          indiqué ici :"),
    tags$div(img(src="ICE_3_familles.png",
                 width = "468px")),
    tags$p(tags$small(
      tags$em("Description de 4 situations d'équilibre/déséquilibre du
           système ongulés-environnement en fonction de l'évolution des trois
           familles d'ICE (abondance en noir, performance en rouge, pression en
           vert). Dans le cas d'une stabilité de l'abondance : (A) équilibre si
           la performance et la pression sont également stables et (B)
           déséquilibre si la performance diminue et la pression augmente
           (ex. : détérioration du milieu). Dans le cas d'une augmentation
           de l'abondance : (A) équilibre si la performance et la pression
           sont stables (ex. : colonisation) et (B) déséquilibre si la
           performance diminue et la pression augmente (Michallet et al.
           2015)."))),
    tags$br(),
    tags$p("Cette analyse se réalise de manière intuitive en choissant les
          paramètres souhaités dans le menu de sélection puis en cliquant sur le
          bouton 'Analyse'."),
    tags$p("Après avoir ajouté un commentaire (facultatif), la sauvegarde de
           l'analyse se fait par l'intermédiaire du bouton 'Téléchargement'."),
    tags$p("Pour plus d'informations sur la manière dont il faut exécuter
           l'analyse, se référer au tutoriel :"),
    tags$video(src = "tendance.mp4",
               controls = "controls",
               width = "468px"),
    tags$p(tags$u(tags$strong("Liste de références :"))),
    tags$ul(list(
      tags$li("Chevrier, T., Pellerin, M., Garel, M., Michallet, J.,
              Saint-Andrieux, C., Hamann, J.-L., Toigo, C., Saïd, S., Klein, F.,
              Morellet, N., Boscardin, Y., Hamard, J.-P. 2015. Fiches
              techniques : Indicateurs de Changement Ecologique. Brochure
              ONCFS, 84 p."),
      tags$li("Michallet, J., Pellerin, M., Garel, M., Chevrier, T., Saïd, S.,
              Baubet, E., Saint-Andrieux, C., Hars, J., Rossi, S., Maillard, D.,
              Klein, F. 2015. Vers une nouvelle gestion du grand gibier : les
              indicateurs de changement écologique. Brochure ONCFS, 68 p.,
              ISBN : 978-2-85692-017-6."),
      tags$li("Morellet, N. 2008. La gestion des grands herbivores par les
              indicateurs de changement écologique. Faune Sauvage, 282, 9-18."),
      tags$li("Morellet, N., Gaillard, J.M., Hewison, A.J.M., Ballon, P.,
              Boscardin, Y., Duncan, P., Klein, F., Maillard, D., 2007.
              Indicators of ecological change: new tools for managing
              populations of large herbivores. J. Appl. Ecol. 44, 634-643. ",
              tags$a(href = "https://doi.org/10.1111/j.1365-2664.2007.01307.x",
                     "doi: 10.1111/j.1365-2664.2007.01307.x"))
    )),
    tags$br(), tags$hr(), tags$br(),
    tags$h3(tags$a(id = "Rapports synthétiques",
                   "Rapports synthétiques")),
    tags$p("TEXTE A REDIGER"),
    tags$br(), tags$hr(), tags$br(),
    tags$h3(tags$a(id = "Documentation",
                   "Documentation")),
    tags$p("TEXTE A REDIGER")
  )
}

projetUI <- function(){
  tagList(
    tags$h1("Le projet ReForest"),
    tags$p("Le projet ReForest a été initié en 2016 dans le but de produire de
           nouvelles méthodes et de nouveaux outils pour améliorer la
           gestion de l'équilibre forêt-gibier. Il s'appuie sur le concept de
           la gestion adaptative. Il regroupe des gestionnaires de la forêt,
           des gestionnaires de la faune sauvage, des représentants de l'état
           et des scientifiques de l'INRAE de la région Centre-Val de Loire. Le
           projet s'articule en neuf étapes : le diagnostic, la définition
           d'objectifs de gestion, l'élaboration de scénarios, l'élaboration
           d'un plan d'action, sa mise en œuvre, la collecte des données, le
           calcul d'indicateurs, la synthèse de l'information et l'évaluation
           des risques."),
    tags$div(img(src='gestion_adaptative.png',
                 width = "720px")),
    # tags$p("Ce projet a permis de mettre en place une méthode de suivis de
    #        l'impact sylvicole des cervidés, en accord avec les acteurs du
    #        projet."),
    # tags$div(img(src="Suivi_impact_Sylvicole.png",
    #              width = "468px")),
    # tags$br(),
    # tags$p("Enfin, il est primordial de faciliter les échanges entre les
    #        acteurs et de standardiser les collectes de données à l'aide d'outils
    #        informatiques. Plusieurs plateformes collaboratives ont ainsi été
    #        mises en place, tel qu'un espace de partage pour la collecte, la
    #        centralisation et le partage des données. Le présente tableau de bord
    #        couvre le domaine spécifique du partage et de l'analyse des données
    #        afin d'orienter les gestionnaires dans leurs prises de décision."),
    tags$p(tags$u(tags$strong("Liste de références :"))),
    tags$ul(list(
      tags$li("Mårell, A., Hamard, J.-P., de Lauriston, A., 2019. La gestion
              adaptative de l'équilibre forêt-gibier : de quoi s'agit-il ?
              Forêt-entreprise 246:58-63.")
    ))
  )
}

equilibreUI <- function(){
  tagList(
    tags$h1("L'équilibre sylvo-cynégétique"),
    tags$p("Entre 1986 et 2012, les réalisations de chasse du cerf élaphe et du
           chevreuil en France ont respectivement été multipliées par 5 et 4,4.
           La chasse en tant qu'indicateur clé des densités de populations
           montre la continuelle progression de ces dernières."),
    tags$p("Plusieurs facteurs expliquent ce fort accroissement, tant
           démographique que géographique, des populations de grand gibier.
           D'une part, la surface forestière en France a connu une forte
           expansion depuis les années 1985, ce qui a favorisé le développement
           des populations. L'augmentation des activités sylvicoles et
           agricoles a amélioré la quantité et la qualité de l'alimentation
           pour les grands herbivores, en fournissant du fourrage ou une
           végétation ligneuse variée et abondante. D'autre part, les
           gestionnaires de la faune, par la pratique d'une chasse
           conservatrice, favorise depuis des décennies l'accroissement des
           populations de grand gibier. Enfin, la disparition des grands
           prédateurs comme le loup et le lynx explique aussi cette progression
           des populations d'ongulés sauvages en France."),
    tags$p("Cependant, les fortes populations de grands gibiers peuvent
           fortement impacter le renouvellement des forêts. En effet,
           l'abroutissement, l'écorçage ou le frottis peuvent compromettre
           l'avenir économique de certains boisements."),
    tags$p("On note que le secteur de l'agriculture peut aussi être touché par
           les populations de cervidés. En effet, cela peut engendrer des
           dommages sur les cultures ou augmenter les risques d'épidémie au sein
           d'élevages. Dans ces cas, nous parlons de déséquilibre
           agro-sylvo-cynégétique."),
    tags$div(img(src="ICE_3_familles.png",
                 width = "468px")),
    tags$p(tags$small(
      tags$em("Description de 4 situations d'équilibre/déséquilibre du
           système ongulés-environnement en fonction de l'évolution des trois
           familles d'ICE (abondance en noir, performance en rouge, pression en
           vert). Dans le cas d'une stabilité de l'abondance : (A) équilibre si
           la performance et la pression sont également stables et (B)
           déséquilibre si la performance diminue et la pression augmente
           (ex. : détérioration du milieu). Dans le cas d'une augmentation
           de l'abondance : (A) équilibre si la performance et la pression
           sont stables (ex. : colonisation) et (B) déséquilibre si la
           performance diminue et la pression augmente (Michallet et al.
           2015)."))),
    tags$br(),
    tags$p(tags$u(tags$strong("Liste de références :"))),
    tags$ul(list(
      tags$li("Beaudesson, P., Maréchal, N., Picard, O. 2013. Un accueil
              équilibré du gibier en forêt. Forêt-entreprise 210:4-10."),
      tags$li("Côté, S.D., Rooney, T.P., Tremblay, J.P., Dussault, C., Waller,
              D.M. 2004. Ecological impacts of deer overabundance. Annual
              Review of Ecology, Evolution and Systematics 35:113-147.",
              tags$a(
                href = "https://doi.org/10.1146/annurev.ecolsys.35.021103.105725",
                "doi: annurev.ecolsys.35.021103.105725")),
      tags$li("Klein, F., Rocquencourt, A., Ballon, P. 2008. Pour un meilleur
              équilibre sylvo-cynégétique : Des pratiques favorables aux
              cervidés.Brochure ONCFS, 56 p."),
      tags$li("Mårell, A., Pellerin, M., Rocquencourt, A., 2012. Mesure de suivi
              de l'empreinte écologique des ongulés sauvages sur la végétation
              forestière. Revue Forestière Française 67, 711-721."),
      tags$li("Michallet, J., Pellerin, M., Garel, M., Chevrier, T., Saïd, S.,
              Baubet, E., Saint-Andrieux, C., Hars, J., Rossi, S., Maillard, D.,
              Klein, F. 2015. Vers une nouvelle gestion du grand gibier : les
              indicateurs de changement écologique. Brochure ONCFS, 68 p.,
              ISBN : 978-2-85692-017-6."),
      tags$li("Morellet, N. 2008. La gestion des grands herbivores par les
              indicateurs de changement écologique. Faune Sauvage, 282, 9-18."),
      tags$li("Morellet, N., Gaillard, J.M., Hewison, A.J.M., Ballon, P.,
              Boscardin, Y., Duncan, P., Klein, F., Maillard, D., 2007.
              Indicators of ecological change: new tools for managing
              populations of large herbivores. J. Appl. Ecol. 44, 634-643. ",
              tags$a(href = "https://doi.org/10.1111/j.1365-2664.2007.01307.x",
                     "doi: 10.1111/j.1365-2664.2007.01307.x")),
      tags$li("Saint-Andrieux, C., Barboiron, A., Corti, R., Benoit, G. 2013.
              Progression des grands ongulés sauvages en France. Forêts de
              France 563:20-21.")
      ))
  )
}

gestionUI <- function(){
  tagList(
    tags$h1("Gestion adaptative"),
    tags$p("La gestion adaptative est une méthode d'analyse cyclique,
           participative, qui évolue en fonction des connaissances et des
           données acquises antérieurement à l'échelle de l'écosystème
           considéré. L'objectif consiste à mieux comprendre la dynamique du
           système afin de réagir de manière concertée pour atteindre les
           objectifs de gestion préalablement fixés. Cette méthode de gestion
           prend en compte des incertitudes et des imprévus ce qui la rend de
           plus en plus pertinente en vue des changements globaux actuels tels
           que le réchauffement climatique ou l'urbanisation généralisée. La
           gestion adaptative s'appuie principalement sur le suivi et le partage
           des données collectées à l'échelle de l'écosystème étudié. Elle
           permet ainsi une réelle interaction entre des acteurs divers tel que
           les scientifiques, les sylviculteurs, les gestionnaires de la faune,
           l'administration, voire diverses associations."),
    tags$p("Lors des premières étapes du cycle, le but est de planifier la
           gestion sur l'année. Cela passe par la définition d'une
           problématique, la mise en place d'objectifs, l'élaboration
           d'hypothèses puis du plan d'action. Lors de ces étapes, tous les
           acteurs se retrouvent pour définir des objectifs dans un premier
           temps, puis les scientifiques doivent s'appuyer sur les données
           disponibles pour créer des modèles prédictifs et mettre en place des
           méthodes de suivi. La suite du cycle repose sur la mise en œuvre du
           plan d'action. Les gestionnaires mettent en place les actions de
           gestion, ils contrôlent et mesure ces dernières et font un retour aux
           scientifiques.Enfin, les dernières étapes du cycle de la gestion
           adaptative concernent l'évaluation et l'apprentissage. Pour cela, les
           scientifiques collectent les données afin d'évaluer l'état de
           l'écosystème et en constituer un suivi. Ils vérifient si les
           résultats obtenus sont en adéquation avec leurs prédictions afin
           d'évaluer la cohérence de leur modèle et d'affiner leurs
           connaissances sur la dynamique du système étudié. Enfin, le cycle
           recommence par une réflexion collective, avec tous les acteurs du
           projet, sur l'état actuel de l'écosystème, les objectifs et les
           méthodes de gestion."),
    tags$div(img(src="cycle_adaptatif.PNG",
                 width = "720px")),
    tags$p(tags$small(
      tags$em("Le processus cyclique de la gestion adaptative (d'après Bacon et
              Guillemain 2018.)")
    )),
    tags$br(),
    tags$div(img(src="ONCFS_GA_prelevements.png",
                 width = "720")),
    # tags$p(tags$small(
    #   tags$em("TEST"))),
    tags$p(tags$small(
      tags$em("Le fonctionnement en double boucle de la gestion adaptative des prélèvements : les données collectées chaque année sont utilisées pour définir la réglementation cynégétique de la saison suivante (boucle bleue), en fonction des objectifs de gestion révisés collectivement à intervalle de quelques années (boucle verte) (modifié d'après Guillemain & Bacon, Alauda, 2019)."))),
    tags$p("Les projets de gestion adaptative se développent de plus en plus.
           Cette approche flexible peut facilement s'adapter à différents
           écosystèmes, différentes espèces ou différentes problématiques. Dans
           le cadre du projet ReForest, le cycle de gestion adaptative a été
           organisé de la façon schématisée ci-dessous :"),
    tags$div(img(src="gestion_adaptative.png",
                 width = "720")),
    tags$p(tags$u(tags$strong("Liste de références :"))),
    tags$ul(list(
      tags$li("Bacon, L., Guillemain, M., 2018. La gestion adaptative des
              prélèvements cynégétiques. Faune Sauvage 320, 4-9."),
      tags$li("Cordonnier, T., Gosselin, F., 2009. La gestion forestière
              adaptative: intégrer l'acquisition de connaissances parmi les
              objectifs de gestion. Révue Forestière Française 61, 131-144."),
      tags$li("Gosselin, F., Cordonnier, T., Bilger, I., Jappiot, M., Chauvin,
              C., Gosselin, M., 2018. Ecological research and environmental
              management: We need different interfaces based on different
              knowledge types. J Environ Manage 218, 388-401.",
              tags$a(href = "https://doi.org/10.1016/j.jenvman.2018.04.025",
                     "doi:10.1016/j.jenvman.2018.04.025")),
      tags$li("Mårell, A., Hamard, J.-P., de Lauriston, A., 2019. La gestion
              adaptative de l'équilibre forêt-gibier : de quoi s'agit-il ?
              Forêt-entreprise 246:58-63.")
      ))
  )
}

glossaireUI <- function(){
  tagList(
    tags$h1("Glossaire"),
    tags$h3(HTML(paste(sapply(unique(df.glossaire$alphabet), function(x){
      as.character(tags$a(href = paste0("#", x), x))
      }), collapse = "|")
    )),
    lapply(unique(df.glossaire$alphabet), function(x) {
      df.temp <- df.glossaire[df.glossaire$alphabet == x, ]
      tagList(tags$h2(tags$a(id = x, x)),
              lapply(df.temp$motclef, function(xdt){
                tagList(tags$dt(xdt),
                        tags$dd(HTML(df.temp$descriptif[df.temp$motclef == xdt]))
                       )
              })
      )
    })
  )
}
