#### MODULE DE CREATION DE FIGURES DYNAMIQUES DANS L'APPLICATION REFOREST ####

### INRAE : Projet ReForest : Création d'un démonstrateur
### Auteur : DUMBO Marie
### Date : 30/06/2020
### Mise-à-jours : cf. Git history for successive modifications by MÅRELL Anders


#---------- ENVIRONNEMENT ----------

`%then%` <- shiny:::`%OR%`


#---------- PREPARATION DES DONNEES ----------

# Liste lieu
sel.location <- function(echelle, lieu){
  v.id <- NULL
  if(echelle == "Région"){
    l.id <- sapply(l.lieu[[lieu]][-1], '[[', "data")[1, ]
    v.id <- unlist(l.id)
  } else if(echelle == "Département"){
    l.id <- sapply(l.lieu, '[[', lieu)[2, ]
    v.id <- sapply(l.id, '[[', 'USC')
  }else{
    v.id <- lieu
  }
  return(v.id)
}


# Concatenation de l'array en fonction du lieu
mysum <- function(x) if (all(is.na(x))) NA else sum(x, na.rm = TRUE)

concat.location <- function(dataset, v.id){
  data <- NULL
  if(dataset == "Cynégétique"){
    i.id.pdc <- which(dimnames(a.pdc)$ID %in% v.id)
    data <- a.pdc[c(i.id.pdc),,,]
    if(length(v.id) > 1){
      data <- apply(data, 2:length(dimnames(data)), sum, na.rm = TRUE)
    }
  } else if(dataset == "ICE"){
    i.id.ice <- which(dimnames(a.ice)$ID %in% v.id)
    data <- a.ice[c(i.id.ice),,,,]
    if(length(i.id.ice) > 1){
      data <- apply(data, 2:length(dimnames(data)), mean, na.rm = TRUE)
    }
  } else {
    i.id.sylv <- which(dimnames(a.sylv)$ID %in% v.id)
    data <- a.sylv[c(i.id.sylv),,,,]
    if(length(v.id) > 1){
      data <- apply(data, 2:length(dimnames(data)), mysum)
    }
  }
  # print(data)
  return(data)
}


#Préparation des données cynégétiques
dataprocess_cyn <- function(indicateur, echelle , lieu, espece){
  data.fin <- NULL
  numerateur = NULL
  denominateur = NULL
  v.id <- sel.location(echelle, lieu)
  # print(v.id)
  data <- concat.location("Cynégétique", v.id)
  suffix.esp <- ""
  if(espece == "Cerf"){
    suffix.esp <- "CE"
  }else{
    suffix.esp <- "CH"
  }
  data <- data[, grep(suffix.esp, dimnames(data)$CATEGORIE), ]
  if (is.na(subset(df.ind, INDICATEUR == indicateur,
                   select = UNITE_ABR))){
    denominateur <- paste0(suffix.esp, "F")
    if(indicateur == "Sexe-ratio (M:F)"){
      numerateur <- paste0(suffix.esp, "M")
    } else{
      numerateur <- paste0(suffix.esp, "J")
    }
  }else{
    abr_indicateur <- subset(df.ind, INDICATEUR == indicateur,
                             select = ABREVIATION)
    # print(abr_indicateur)
    numerateur <- substr(abr_indicateur, 2 , 4)
  }
  if(is.null(denominateur)){
    # print(data[, numerateur, ])
    # print(data)
    # print(apply(data, c(1, 3), FUN = sum, na.rm = TRUE))
    data.fin <- 100 *
      (data[, numerateur, ] / (apply(data, c(1, 3), FUN = sum, na.rm = TRUE)))
  }else{
    # print(data[, numerateur, ])
    # print(data[, denominateur, ])
    data.fin <- data[, numerateur, ] / data[, denominateur, ]
  }
  # print(data.fin)
  return(data.fin)
}


# Préparation des données ICE
dataprocess_ice <- function(indicateur, espece, echelle, lieu){
  erreur <- "Désolé, aucune donnée n'est disponible pour cette localisation."
  v.id <- sel.location(echelle, lieu)
  data <- concat.location("ICE", v.id)
  if(length(dim(data))==5){
    return(erreur)
  }
  data <- data[,espece,indicateur,1:3]
  i.na <- which(apply(data,1, function(x) all(is.na(x))))
  data <- data[-c(i.na),]
  if(all(is.na(data))){
    return(erreur)
  }
  data
}


#Préparation des données sylvicoles
dataprocess_sylv <- function(indicateur, echelle, lieu) {
  v.id <- sel.location(echelle, lieu)
  data <- concat.location("Sylvicole", v.id)
  # print(dimnames(data))
  if(indicateur ==
     "Notation 'Gibier' de l'ONF (HT<3m, forêts publiques)"){
    data <- data[ , "Notation 'Gibier' de l'ONF (HT<3m, forêts publiques)",
                  c("Etat satisfaisant",
                      "Etat dégradé",
                      "Etat compromis"), "VALEUR"]
  } else if(indicateur ==
           "Notation 'Gibier' de l'ONF (HT>3m, forêts publiques)"){
    data <- data[ , "Notation 'Gibier' de l'ONF (HT>3m, forêts publiques)",
                  c("Etat satisfaisant",
                    "Etat dégradé",
                    "Etat compromis"), "VALEUR"]
  } else if(indicateur ==
            "Notation 'Abroutissement sur les essences objectifs' du CRPF"){
    data <-
      data[ ,
            "Notation 'Abroutissement sur les essences objectifs' du CRPF",
            c("Absent ou rare",
              "Sporadique",
              "Fréquent"), "VALEUR"]
  } else if(indicateur ==
            "Notation 'Abroutissement sur la végétation d'accompagnement' du CRPF"){
    data <-
      data[ ,
            "Notation 'Abroutissement sur la végétation d'accompagnement' du CRPF",
            c("Absent ou rare",
              "Sporadique",
              "Fréquent"), "VALEUR"]
  } else if(indicateur ==
            "Notation 'Ecorçage sur les essences objectifs' du CRPF"){
    data <-
      data[ ,
            "Notation 'Ecorçage sur les essences objectifs' du CRPF",
            c("Absent ou rare",
              "Sporadique",
              "Fréquent"), "VALEUR"]
  } else if(grepl("Peuplements sensibles", indicateur)) {
    data.foret <-
      data["2017", "Structure foncière de la forêt",
           c("Surface de forêts publiques",
             "Surface de forêts privées sans DGD",
             "Surface de forêt privée soumise à un document de gestion"), "SURFACE"]
    # print(head(data.foret))
    # Calculate the sum of forest cover data
    dataSumsForet <- sum(data.foret, na.rm = TRUE)
    # print(dataSumsForet)
    dataSumsFpubl <- data.foret["Surface de forêts publiques"]
    # print(dataSumsFpubl)
    rm(data.foret)
    data <-
      data[, "Peuplements sensibles",
           c(
             "Surface d'interventions sylvicoles par télédétection",
             "Surface de peuplements en phase de renouvellement (HT<3m, forêts publiques)",
             "Surface de peuplements en phase de renouvellement (HT>3m, forêts publiques)"
             ), "SURFACE"]
    # print(dimnames(data))
    # Calculate the percentage of forest renewal per category
    MySelection <- c("Surface d'interventions sylvicoles par télédétection")
    data[, MySelection] <- data[, MySelection] / dataSumsForet * 100
    MySelection <-
      c("Surface de peuplements en phase de renouvellement (HT<3m, forêts publiques)")
    # print(summary(data[, MySelection]))
    data[, MySelection] <- data[, MySelection] / dataSumsFpubl * 100
    MySelection <-
      c("Surface de peuplements en phase de renouvellement (HT>3m, forêts publiques)")
    data[, MySelection] <- data[, MySelection] / dataSumsFpubl * 100
    dimnames(data)$CATEGORIE <- sub("Surface", "Taux", dimnames(data)$CATEGORIE)
  } else if(grepl("Structure foncière", indicateur)) {
    data <- data[, "Structure foncière de la forêt", , "SURFACE"]
  } else{
    data <- data[, indicateur, , "VALEUR"]
  }
  if(all(is.na(data))){
    return("Désolé, aucune donnée n'est disponible pour cette unité de
           gestion.")
  }
  return(data)
}


dataprocess_barplot <- function(indicateur, echelle, lieu, an) {
  erreur <- "Désolé, aucune donnée n'est disponible pour cette année."
  v.id <- sel.location(echelle, lieu)
  data <- concat.location("Sylvicole", v.id)
  # print(dimnames(data))
  if(indicateur == "Structure foncière de la forêt (Surface totale)"){
    # print(dimnames(data))
    # print(class(data))
    # print(an)
    data <- data[as.character(an), "Structure foncière de la forêt",
                 c("Surface de forêts publiques",
                   "Surface de forêts privées sans DGD",
                   "Surface de forêt privée soumise à un document de gestion",
                   "Surface d'autres occupations du sol"), "SURFACE"]
    #print(data)
    # split.names.data <- sapply(names(data),
    #                            function(x) strsplit(x,"(", fixed=TRUE))
    # names(data) <- sapply(split.names.data, '[')[1,]
    dataSums <- sum(data, na.rm = TRUE)
    # Calculate the percentage of land occupancy per category
    data <- data / dataSums * 100
    names(data) <- sub("Surface", "Taux", names(data))
    # print(data)
  } else if(indicateur ==
            "Structure foncière de la forêt (Surface forestière)") {
    data <- data[as.character(an), "Structure foncière de la forêt",
                 c("Surface de forêts publiques",
                   "Surface de forêts privées sans DGD",
                   "Surface de forêt privée soumise à un document de gestion"),
                 "SURFACE"]
    # split.names.data <- sapply(names(data),
    #                            function(x) strsplit(x,"(", fixed=TRUE))
    # names(data) <- sapply(split.names.data, '[')[1,]
    dataSums <- sum(data, na.rm = TRUE)
    # Calculate the percentage of land occupancy per category
    data <- data / dataSums * 100
    names(data) <- sub("Surface", "Taux", names(data))
  } else if(indicateur ==
            "Composition en essences") {
    data <- data[as.character(an), "Composition en essences",
                 c("Surface de forêts mélangées",
                   "Surface de forêts de résineux",
                   "Surface de forêts de feuillus"), "SURFACE"]
    dataSums <- sum(data, na.rm = TRUE)
    # Calculate the percentage of land occupancy per category
    data <- data / dataSums * 100
    names(data) <- sub("Surface", "Taux", names(data))
  } else if(indicateur ==
            "Taux de boisement") {
    data <- data[as.character(an), "Structure foncière de la forêt",
                 c("Surface de forêts publiques",
                   "Surface de forêts privées sans DGD",
                   "Surface de forêt privée soumise à un document de gestion",
                   "Surface d'autres occupations du sol"), "SURFACE"]
    # Calculate total surface per unit
    dataSums <- sum(data, na.rm = TRUE)
    # Calculate total forest surface
    dataSumsForet <- sum(data[
      c("Surface de forêts publiques",
        "Surface de forêts privées sans DGD",
        "Surface de forêt privée soumise à un document de gestion")],
      na.rm = TRUE)
    names(dataSumsForet) <- "Surface de forêts"
    data <- c(data["Surface d'autres occupations du sol"], dataSumsForet)
    names(data) <- c("Surface d'autres occupations du sol", "Surface de forêts")
    # Calculate the percentage of land occupancy per category
    data <- data / dataSums * 100
    names(data) <- sub("Surface", "Taux", names(data))
  } else {
    # print("test")
    tryCatch(
      data <- data[as.character(an),
                   c("Taux de forêts mélangées",
                     "Taux de forêts de résineux",
                     "Taux de forêts de feuillus"), "VALEUR"],
      error = return(erreur)
    )
  }
  # print(data)
  if(all(is.na(data))){
    return(erreur)
  }
  # print(data)
  return(data)
  # print(dim(data))
}


dataprocess_map <- function(indicateur, espece, annee, echelle) {
  df.data <- NULL
  # print(espece)
  if(indicateur == "Taux de réalisation (ratio real:attr)" ){
    if(espece == "CET") {
      suffix.esp <- "CE"
      data <- a.pdc[, as.character(annee), grep(suffix.esp,
                                                dimnames(a.pdc)$CATEGORIE), ]
      data <- apply(data, c(1, 3), FUN = sum, na.rm = TRUE)
      # print(summary(data))
      data <- data[,2]/data[,1]
      df.data <- data.frame(names(data), data, row.names = NULL)
    } else if(espece == "CHT") {
      espece <- "CHI"
      data <- a.pdc[, as.character(annee), espece, ]
      # print(summary(data))
      data <- data[,2]/data[,1]
      df.data <- data.frame(names(data), data, row.names = NULL)
    } else {
    data <- a.pdc[, as.character(annee), espece, ]
    # print(summary(data))
    data <- data[,2]/data[,1]
    df.data <- data.frame(names(data), data, row.names = NULL)
    }
  } else {
    strInd <- strsplit(indicateur," - ", fixed = TRUE)[[1]]
    ind <- strInd[1]
    # print(head(data))
    if(ind == "Plan de Chasse aux 100 ha"){
      if(espece == "CET"){
        suffix.esp <- "CE"
        data <- a.pdc[, as.character(annee), grep(suffix.esp,
                                                  dimnames(a.pdc)$CATEGORIE), ]
        data <- apply(data, c(1, 3), FUN = sum, na.rm = TRUE)
        data <- data.frame(rownames(data), data[, strInd[[2]]],
                           row.names = NULL)
        colnames(data) <- c("ID", "VALEUR")
        data <- merge(data, df.aire, by = "ID", all = TRUE)
        # print(data)
        df.data <- data.frame(data$ID, 100 * (data$VALEUR / data$TOT_AREA),
                              row.names = NULL)
      } else if(espece == "CHT"){
        espece <- "CHI"
        data <- a.pdc[, as.character(annee), espece, ]
        data <- data.frame(rownames(data), data[, strInd[2]], row.names = NULL)
        colnames(data) <- c("ID", "VALEUR")
        data <- merge(data, df.aire, by = "ID", all = TRUE)
        df.data <- data.frame(data$ID, 100 * (data$VALEUR / data$TOT_AREA),
                              row.names = NULL)
      } else{
        # print(espece)
        data <- a.pdc[, as.character(annee), espece,]
        data <- data.frame(rownames(data), data[, strInd[2]], row.names = NULL)
        colnames(data) <- c("ID", "VALEUR")
        data <- merge(data, df.aire, by = "ID", all = TRUE)
        df.data <- data.frame(data$ID, 100 * (data$VALEUR / data$TOT_AREA),
                              row.names = NULL)
      }
    } else if(espece == "CET") {
      suffix.esp <- "CE"
      data <- a.pdc[, as.character(annee), grep(suffix.esp,
                                                dimnames(a.pdc)$CATEGORIE), ]
      data <- apply(data, c(1, 3), FUN = sum, na.rm = TRUE)
      data <- data.frame(rownames(data), data[, strInd[[2]]], row.names = NULL)
      colnames(data) <- c("ID", "VALEUR")
      data <- merge(data, df.aire, by = "ID", all = TRUE)
      df.data <- data.frame(data$ID, 100 * (data$VALEUR / data$BOIS_AREA),
                            row.names = NULL)
    } else if(espece == "CHT") {
      espece <- "CHI"
      data <- a.pdc[, as.character(annee), espece,]
      data <- data.frame(rownames(data), data[, strInd[2]], row.names = NULL)
      colnames(data) <- c("ID", "VALEUR")
      data <- merge(data, df.aire, by = "ID", all = TRUE)
      df.data <- data.frame(data$ID, 100 * (data$VALEUR / data$BOIS_AREA),
                            row.names = NULL)

    } else {
      print(paste(as.character(annee), espece))
      data <- a.pdc[, as.character(annee), espece, ]
      data <- data.frame(rownames(data), data[, strInd[2]], row.names = NULL)
      colnames(data) <- c("ID", "VALEUR")
      data <- merge(data, df.aire, by = "ID", all = TRUE)
      df.data <- data.frame(data$ID, 100 * (data$VALEUR / data$BOIS_AREA),
                            row.names = NULL)
    }
  }
  colnames(df.data) <- c("IDENTIFIANT", "VALEUR")
  # print(head(df.data))
  df.data
}


dataprocess_mapdyn <- function(dataset, tableau, indicateurgeo, cible,
                               indicateur, espece, annee, echelle) {
  df.data <- NULL
  numerateur <- NULL
  denominateur <- NULL
  suffix.esp <- NULL

  # Les données et indicateurs de statistiques de chasse
  # print(dataset)
  # print(tableau)
  # print(cible)
  # print(indicateur)
  # print(espece)
  # print(annee)
  # print(echelle)
  if(dataset == "Cynégétique"){
    strInd <- strsplit(indicateur," - ", fixed = TRUE)[[1]]
    ind <- strInd[1]
    # print(paste("Check:", ind))
    # Aux 100 ha
    if(ind == "Plan de Chasse aux 100 ha") {
      if(espece == "CET"){
        suffix.esp <- "CE"
        data <- a.pdc[, as.character(annee), grep(suffix.esp,
                                                  dimnames(a.pdc)$CATEGORIE), ]
        # ifelse statement to keep all.NA as NA instead of zero
        data <-
          apply(data, c(1, 3),
                FUN = function(x) {
                  ifelse(all(is.na(x)), NA, sum(x, na.rm = TRUE))
                })
        # print(dimnames(data))
        # print(strInd[[2]])
        data <- data.frame(ID = rownames(data),
                           VALEUR = data[, tableau],
                           row.names = NULL)
        data <- merge(data, df.aire, by = "ID", all = TRUE)
        # print(head(data))
        df.data <- data.frame(ID = data$ID,
                              VALEUR = 100 * (data$VALEUR / data$TOT_AREA),
                              row.names = NULL)
        # print(head(df.data))
      } else if(espece == "CHT") {
        espece <- "CHI"
        data <- a.pdc[, as.character(annee), espece, ]
        data <- data.frame(ID = rownames(data),
                           VALEUR = data[, tableau],
                           row.names = NULL)
        data <- merge(data, df.aire, by = "ID", all = TRUE)
        df.data <- data.frame(ID = data$ID,
                              VALEUR = 100 * (data$VALEUR / data$TOT_AREA),
                              row.names = NULL)
      } else {
        # print(espece)
        data <- a.pdc[, as.character(annee), espece,]
        data <- data.frame(ID = rownames(data),
                           VALEUR = data[, tableau],
                           row.names = NULL)
        data <- merge(data, df.aire, by = "ID", all = TRUE)
        df.data <- data.frame(ID = data$ID,
                              VALEUR = 100 * (data$VALEUR / data$TOT_AREA),
                              row.names = NULL)
      }
    # Aux 100 ha boisés
    } else if(ind == "Plan de Chasse aux 100 ha boisés") {
      if(espece == "CET") {
        suffix.esp <- "CE"
        data <- a.pdc[, as.character(annee), grep(suffix.esp,
                                                  dimnames(a.pdc)$CATEGORIE), ]
        # ifelse statement to keep all.NA as NA instead of zero
        data <-
          apply(data, c(1, 3),
                FUN = function(x) {
                  ifelse(all(is.na(x)), NA, sum(x, na.rm = TRUE))
                })
        data <- data.frame(rownames(data), data[, tableau], row.names = NULL)
        colnames(data) <- c("ID", "VALEUR")
        data <- merge(data, df.aire, by = "ID", all = TRUE)
        df.data <- data.frame(data$ID, 100 * (data$VALEUR / data$BOIS_AREA),
                              row.names = NULL)
      } else if(espece == "CHT") {
        espece <- "CHI"
        data <- a.pdc[, as.character(annee), espece,]
        data <- data.frame(rownames(data), data[, tableau], row.names = NULL)
        colnames(data) <- c("ID", "VALEUR")
        data <- merge(data, df.aire, by = "ID", all = TRUE)
        df.data <- data.frame(data$ID, 100 * (data$VALEUR / data$BOIS_AREA),
                              row.names = NULL)

      } else {
        # print(paste(as.character(annee), espece))
        data <- a.pdc[, as.character(annee), espece, ]
        data <- data.frame(rownames(data), data[, tableau], row.names = NULL)
        colnames(data) <- c("ID", "VALEUR")
        data <- merge(data, df.aire, by = "ID", all = TRUE)
        df.data <- data.frame(data$ID, 100 * (data$VALEUR / data$BOIS_AREA),
                              row.names = NULL)
      }
    # Les taux de réalisations
    } else if(indicateur == "Taux de réalisation (ratio real:attr)") {
      if(espece == "CET") {
        suffix.esp <- "CE"
        data <- a.pdc[, as.character(annee), grep(suffix.esp,
                                                  dimnames(a.pdc)$CATEGORIE), ]
        data <- apply(data, c(1, 3), FUN = sum, na.rm = TRUE)
        # print(summary(data))
        data <- data[,2]/data[,1]
        df.data <- data.frame(names(data), data, row.names = NULL)
      } else if(espece == "CHT") {
        espece <- "CHI"
        data <- a.pdc[, as.character(annee), espece, ]
        # print(summary(data))
        data <- data[,2]/data[,1]
        df.data <- data.frame(names(data), data, row.names = NULL)
      } else {
        data <- a.pdc[, as.character(annee), espece, ]
        # print(summary(data))
        data <- data[,2]/data[,1]
        df.data <- data.frame(names(data), data, row.names = NULL)
      }
    # Les indicateurs de ratio et de proportion (J:F, M:F, %F, %M et %J)
    } else {
      if(espece == "Cerf") {
        suffix.esp <- "CE"
      } else {
        suffix.esp <- "CH"
      }
      data <- a.pdc[, as.character(annee),
                    grep(suffix.esp, dimnames(a.pdc)$CATEGORIE), tableau]
      # print(head(data))
      # Différencier les ratio (sans unité) et les proportions (avec unité %)
      # Les ratios
      if (is.na(subset(df.ind, INDICATEUR == indicateur,
                       select = UNITE_ABR))){
        denominateur <- paste0(suffix.esp, "F")
        if(indicateur == "Sexe-ratio (M:F)") {
          numerateur <- paste0(suffix.esp, "M")
        } else {
          numerateur <- paste0(suffix.esp, "J")
        }
      # Les proportions
      } else {
        abr_indicateur <- subset(df.ind, INDICATEUR == indicateur,
                                 select = ABREVIATION)
        # print(abr_indicateur)
        numerateur <- substr(abr_indicateur, 2 , 4)
      }
      # Les proportions
      if(is.null(denominateur)) {
        # print(head(data))
        # print(data)
        # print(apply(data, c(1, 3), FUN = sum, na.rm = TRUE))
        df.data <-
          data.frame(ID = dimnames(data)[1],
                     VALEUR = 100 *
                       (data[, numerateur] /
                          (apply(data, c(1), FUN = sum, na.rm = TRUE))))
      } else {
        # print(head(data))
        # print(data[, denominateur])
        df.data <-
          data.frame(ID = dimnames(data)[1],
                     VALEUR = data[, numerateur] / data[, denominateur])
      }
    }
  # Les données d'Indicateurs de Changement Ecologique
  } else if(dataset == "ICE"){
    data <- a.ice
  # Les données d'indicateurs sylvicoles
  } else if(dataset == "Sylvicole") {
    # print("test")
    # print(indicateur)
    if(indicateur == "Structure foncière de la forêt (Surface totale)") {
      # print("test")
      data <-
        a.sylv[, as.character(annee), "Structure foncière de la forêt",
               c("Surface de forêts publiques",
                 "Surface de forêts privées sans DGD",
                 "Surface de forêt privée soumise à un document de gestion",
                 "Surface d'autres occupations du sol"), "SURFACE"]
      # Calculate the sum of all surfaces
      # print(data)
      dataSums <- apply(data, c(1), sum, na.rm = TRUE)
      # print(dataSums)
      # Calculate the percentage of land occupancy per category
      data <- data / dataSums * 100
      #print(data)
      dimnames(data)$CATEGORIE <- sub("Surface", "Taux",
                                      dimnames(data)$CATEGORIE)
      # print(dim(data))
      # print(tableau)
      df.data <- data.frame(rownames(data), data[, tableau], row.names = NULL)
      # print(head(df.data))
    } else if(
      indicateur == "Structure foncière de la forêt (Surface forestière)") {
      data <-
        a.sylv[, as.character(annee), "Structure foncière de la forêt",
               c("Surface de forêts publiques",
                 "Surface de forêts privées sans DGD",
                 "Surface de forêt privée soumise à un document de gestion"),
               "SURFACE"]
      # Calculate the sum of all surfaces
      dataSums <- apply(data, c(1), sum, na.rm = TRUE)
      # Calculate the percentage of land occupancy per category
      data <- data / dataSums * 100
      dimnames(data)$CATEGORIE <- sub("Surface", "Taux",
                                      dimnames(data)$CATEGORIE)
      df.data <- data.frame(rownames(data), data[, tableau], row.names = NULL)
    } else if(
      indicateur == "Taux de boisement") {
      data <-
        a.sylv[, as.character(annee), "Structure foncière de la forêt",
               c("Surface de forêts publiques",
                 "Surface de forêts privées sans DGD",
                 "Surface de forêt privée soumise à un document de gestion",
                 "Surface d'autres occupations du sol"), "SURFACE"]
      # Calculate the sum of all surfaces
      dataSums <- apply(data, c(1), sum, na.rm = TRUE)
      # Calculate the sum of forest surface
      dataSumsForet <-
        apply(data[, c("Surface de forêts publiques",
                       "Surface de forêts privées sans DGD",
                       "Surface de forêt privée soumise à un document de gestion")],
              c(1), sum, na.rm = TRUE)
      data <- cbind(data[, "Surface d'autres occupations du sol"],
                    dataSumsForet)
      names(dimnames(data)) <- list("ID", "CATEGORIE")
      dimnames(data)$CATEGORIE <- c("Surface d'autres occupations du sol",
                                    "Surface de forêts")
      # Calculate the percentage of land occupancy per category
      data <- data / dataSums * 100
      dimnames(data)$CATEGORIE <- sub("Surface", "Taux",
                                      dimnames(data)$CATEGORIE)
      df.data <- data.frame(rownames(data), data[, tableau], row.names = NULL)
    } else if(
      indicateur == "Peuplements sensibles") {
      # print(dimnames(a.sylv)[2:4])
      data <-
        a.sylv[, as.character(annee), "Peuplements sensibles",
               c("Surface d'interventions sylvicoles par télédétection",
                 "Surface de peuplements en phase de renouvellement (HT<3m, forêts publiques)",
                 "Surface de peuplements en phase de renouvellement (HT>3m, forêts publiques)"),
               "SURFACE"]
      MyYears <- apply(a.sylv[, , "Structure foncière de la forêt", , "SURFACE"], c(2),
                       function(x) all(is.na(x)))
      MyYears <- names(MyYears[MyYears == FALSE]) # Keep years with data
      MyYears <- MyYears[which.min(abs(as.numeric(MyYears) - as.numeric(annee)))]
      data.foret <-
        a.sylv[, as.character(MyYears),
               "Structure foncière de la forêt",
               c("Surface de forêts publiques",
                 "Surface de forêts privées sans DGD",
                 "Surface de forêt privée soumise à un document de gestion"),
               "SURFACE"]
      # Calculate the sum of forest cover data
      dataSumsForet <- apply(data.foret, c(1), sum, na.rm = TRUE)
      # print(head(dataSumsForet))
      dataSumsFpubl <-
        a.sylv[, as.character(MyYears), "Structure foncière de la forêt",
               c("Surface de forêts publiques"), "SURFACE"]
      # print(summary(dataSumsFpubl))
      rm(data.foret)
      # Calculate the percentage of land occupancy per category
      MySelection <- c("Surface d'interventions sylvicoles par télédétection")
      data[, MySelection] <- data[, MySelection] / dataSumsForet * 100
      MySelection <-
        c("Surface de peuplements en phase de renouvellement (HT<3m, forêts publiques)")
      # print(summary(data[, MySelection]))
      data[, MySelection] <- data[, MySelection] / dataSumsFpubl * 100
      MySelection <-
        c("Surface de peuplements en phase de renouvellement (HT>3m, forêts publiques)")
      data[, MySelection] <- data[, MySelection] / dataSumsFpubl * 100
      dimnames(data)$CATEGORIE <- sub("Surface", "Taux",
                                      dimnames(data)$CATEGORIE)
      df.data <- data.frame(rownames(data), data[, tableau], row.names = NULL)
      # print(df.data[which.max(df.data[, 2]),])
      # print(head(df.data))
    } else if(
      indicateur == "Notation 'Gibier' de l'ONF") {
      # print(dimnames(a.sylv)[2:4])
      if(tableau == "Peuplements HT<3m (forêts publiques)") {
        data <-
          a.sylv[, as.character(annee),
                 "Notation 'Gibier' de l'ONF (HT<3m, forêts publiques)",
                 c("Etat satisfaisant",
                   "Etat dégradé",
                   "Etat compromis"), ]
      } else {
        data <-
          a.sylv[, as.character(annee),
                 "Notation 'Gibier' de l'ONF (HT>3m, forêts publiques)",
                 c("Etat satisfaisant",
                   "Etat dégradé",
                   "Etat compromis"), ]
      }
      # Calculate weighted mean
      res1 <- data[, "Etat satisfaisant", "SURFACE"] * 1
      res2 <- data[, "Etat dégradé", "SURFACE"] * 2
      res3 <- data[, "Etat compromis", "SURFACE"] * 3
      res4 <- rowSums( cbind (res1, res2, res3), na.rm = TRUE)
      # print(head(res4))
      rm(res1, res2, res3)
      res4 <- res4 / rowSums(cbind(data[, "Etat satisfaisant", "SURFACE"],
                        data[, "Etat dégradé", "SURFACE"],
                        data[, "Etat compromis", "SURFACE"]), na.rm = TRUE)
      # print(names(res4))
      df.data <- data.frame(names(res4), res4, row.names = NULL)
      rm(res4)
      # print(df.data[which.max(df.data[, 2]),])
      # print(head(df.data))
    } else if(
      indicateur == "Notation 'Gibier' du CRPF") {
      # print(dimnames(a.sylv)[2:4])
      if(tableau == "Abroutissement sur les essences 'objectif'") {
        data <-
          a.sylv[, as.character(annee),
                 "Notation 'Gibier' du CRPF (Abroutissement sur les essences 'objectif')",
                 c("Absent ou rare",
                   "Sporadique",
                   "Fréquent"), ]
      } else if(tableau == "Abroutissement sur la végétation d'accompagnement") {
        data <-
          a.sylv[, as.character(annee),
                 "Notation 'Gibier' du CRPF (Abroutissement sur la végétation d'accompagnement)",
                 c("Absent ou rare",
                   "Sporadique",
                   "Fréquent"), ]
      } else {
        data <-
          a.sylv[, as.character(annee),
                 "Notation 'Gibier' du CRPF (Ecorçage sur les essences 'objectif')",
                 c("Absent ou rare",
                   "Sporadique",
                   "Fréquent"), ]
      }
      # Calculate weighted mean
      res1 <- data[, "Absent ou rare", "SURFACE"] * 1
      res2 <- data[, "Sporadique", "SURFACE"] * 2
      res3 <- data[, "Fréquent", "SURFACE"] * 3
      res4 <- rowSums( cbind (res1, res2, res3), na.rm = TRUE)
      # print(head(res4))
      rm(res1, res2, res3)
      res4 <- res4 / rowSums(cbind(data[, "Absent ou rare", "SURFACE"],
                                   data[, "Sporadique", "SURFACE"],
                                   data[, "Fréquent", "SURFACE"]), na.rm = TRUE)
      # print(names(res4))
      df.data <- data.frame(names(res4), res4, row.names = NULL)
      rm(res4)
      # print(df.data[which.max(df.data[, 2]),])
      # print(head(df.data))
    } else if(
      indicateur == "Composition en essences") {
      data <-
        a.sylv[, as.character(annee), "Composition en essences", , "SURFACE"]
      # Calculate the sum of all surfaces
      dataSums <- apply(data, c(1), sum, na.rm = TRUE)
      # Calculate the percentage of occupancy per forest type
      data <- data / dataSums * 100
      dimnames(data)$CATEGORIE <- sub("Surface", "Taux",
                                      dimnames(data)$CATEGORIE)
      df.data <- data.frame(rownames(data), data[, tableau], row.names = NULL)
    }
  } else  {
    data <- a.sylv
  }

  # print(head(df.data))
  colnames(df.data) <- c("IDENTIFIANT", "VALEUR")
  if(echelle == "Département") {
    MyDepList <- dimnames(sapply(l.lieu, "[", 2:7))[[1]]
    MyUGList <- sapply(sapply(sapply(l.lieu, "[", 2:7), "[", 2), "[", 1)
    names(MyUGList) <- NULL
    MyDepList <- unlist(mapply(function(x, y) {
      id_dep <- rep(y, length(unlist(x)[unlist(x) %in% df.data$ID]))
    }, MyUGList, MyDepList))
    df.data$id_dep <- MyDepList
    df.data <- aggregate(VALEUR ~ id_dep,
                         data = df.data,
                         FUN = mean,
                         na.rm = TRUE)
    names(df.data) <- c("IDENTIFIANT", "VALEUR")
    # print(head(df.data))
    if(indicateurgeo == "Indicateur standardisé") {
      df.data$VALEUR <- Zscores(df.data$VALEUR, cible = cible)
    }
  } else if(echelle == "Unité de gestion") {
    if(indicateurgeo == "Indicateur standardisé") {
      df.data$VALEUR <- Zscores(df.data$VALEUR, cible = cible)
    }
  }
  # print(summary(df.data))
  df.data
}

addColorsMap <- function(data, D1, Q1, M, Q3, D9) {
  # print(data[which(is.na(data$VALEUR)), c("ID", "VALEUR")])
  # print(data$VALEUR > D9)
  # print(paste(D9, class(D9), v.couleur[8]))
  data[["COULEUR"]] <- NA
  data[which(data$VALEUR <= D1), "COULEUR"] <- v.couleur[46]
  data[which(data$VALEUR > D1), "COULEUR"] <- v.couleur[45]
  data[which(data$VALEUR > Q1), "COULEUR"] <- v.couleur[5]
  data[which(data$VALEUR > M), "COULEUR"] <- v.couleur[6]
  data[which(data$VALEUR > Q3), "COULEUR"] <- v.couleur[7]
  data[which(data$VALEUR > D9), "COULEUR"] <- v.couleur[8]
  data[which(is.na(data$VALEUR)), "COULEUR"] <- v.couleur[50]
  data[which(is.infinite(data$VALEUR)), "COULEUR"] <- "#000000"
  data[which(data$VALEUR == 0), "COULEUR"] <- "#FFFFFF"
  data[which(is.na(data$COULEUR)), "COULEUR"] <- "red"
  # print(head(data[c("ID", "VALEUR", "COULEUR")]))
  # print(data[which(is.na(data$VALEUR)), c("ID", "VALEUR", "COULEUR")])
  data
}


Zscores <- function(valeurs, cible = NULL) {
  # print(cible)
  # print(var(valeurs[is.finite(valeurs)], na.rm = TRUE))
  if(is.null(cible) | is.na(cible)) {
    if(var(valeurs[is.finite(valeurs)], na.rm = TRUE) == 0) {
      z <- rep(0, length(valeurs))
    } else {
      mu <- mean(valeurs[is.finite(valeurs)], na.rm = TRUE)
      stdev <- sd(valeurs[is.finite(valeurs)], na.rm = TRUE)
      z <- (valeurs - mu) / stdev
    }
  } else if(var(valeurs[is.finite(valeurs)], na.rm = TRUE) == 0) {
    z <- valeurs - cible
  } else {
    stdev <- sd(valeurs[is.finite(valeurs)], na.rm = TRUE)
    z <- (valeurs - cible) / stdev
  }
  z
}


#---------- CONSTRUCTION DES GRAPHIQUE ----------

# Diviseur pour des titres trop longs
string_wrapper <- function(MonTexte, largeur) {
  sapply(MonTexte, FUN = function(x) {
    paste(strwrap(x, width = largeur),
          collapse = "\n")
  })
}

string_wrapper_html <- function(MonTexte, largeur) {
  sapply(MonTexte, FUN = function(x) {
    paste(strwrap(x, width = largeur),
          collapse = "</br>")
  })
}

# Choix du type de graphique
plotType <- function(data , type, titre, axeTitre, description, echelle){
  # print(type)
  # print(data)
  # print(titre)
  switch (type,
          simple = simpleGraph(data, titre, axeTitre, description),
          histo = histo(data, titre, axeTitre, description),
          ice = ice_graph(data, titre, axeTitre, description),
          carte = simpleMap(data, titre, description, echelle)
  )
}


# Graphiques lignes et points
simpleGraph <- function(d, titre, ytitre, description){
  DataToKeep <- apply(d, c(2),
                   function(x) all(is.na(x)))
  DataToKeep <- names(
    DataToKeep[DataToKeep == FALSE]) # Keep years with data
  d <- d[, DataToKeep, drop = FALSE]

  # if(anyNA(d)){
  #   d <- na.omit(d)
  # }

  # print(titre)
  # print(d)
  # print(dimnames(d))
  MaTitre <- string_wrapper(titre, 50)
  nb_lignes <- sapply(gregexpr("\n", MaTitre), length) - 1
  MyMar <- par()$mar
  MyMar[3] <- MyMar[3] + nb_lignes
  par(mar = MyMar)

  MaYtitre <- string_wrapper(ytitre, 50)
  nb_lignes <- sapply(gregexpr("\n", MaYtitre), length) - 1
  MyMar <- par()$mar
  MyMar[2] <-MyMar[2] + nb_lignes

  MaSub <- string_wrapper(paste0("Source : ", description), 75)
  nb_lignes <- sapply(gregexpr("\n", MaSub), length) - 1
  MyMar <- par()$mar
  MyMar[1] <- MyMar[1] + nb_lignes
  par(mar = MyMar)
  # print(MaSub)

  # print(dimnames(d)[2])
  MaLabels <- unlist(lapply(dimnames(d)[2], function(x) string_wrapper(x, 35)))
  nb_lignes <- sapply(gregexpr("\n", MaLabels), length) - 1

  plot <- matplot(x = rownames(d), y = d,
          xlab = "Années",
          ylab = ytitre,
          main = MaTitre,
          # sub = paste("source : ", description), # Titre et texte
          type = "n", # ligne et point
          # pch = 20, lty = 1, # Type de point et de ligne
          # lwd = 3, # Epaisseur trait
          las = 1, # Orientation texte axes
          # col = v.couleur[1:dim(d)[2]], # Couleur des graphs
          font.main = 2, font.lab = 3, # Style d'écriture
          bty = 'l'#, # Style de cadre de la figure
          # pty = 's' # Figure de forme carré
  )

  # print(1 + max(nb_lignes))
  # print(MaLabels)
  if(!is.null(colnames(d))){
    legend('topleft',
           legend = MaLabels,
           bty = "n",
           y.intersp = 1 + 0.5 * nb_lignes,
           lty = 1,
           lwd = 1,
           col = v.couleur[1:dim(d)[2]] )
  }

  MyList <- as.list(unlist(dimnames(d)[2]))
  MyColors <- as.list(unlist(v.couleur[1:dim(d)[2]]))
  # print(MyColors)
  plot <- mapply(function(x, y) {
    # print(paste(x, y))
    MyData <- d[, x]
    if(anyNA(MyData)) {
      MyData <- na.omit(MyData)
    }
    # print(MyData)
    # print(names(MyData))
    matpoints(x = names(MyData), y = MyData,
              type = "b", #ligne et point
              pch = 20, lty = 1, # Type de point et de ligne
              lwd = 3, # Epaisseur trait
              col = y
    )
  }, MyList, MyColors)

  # Ajouter des informations sur les sources
  mtext(text = MaSub, side = 1, line = 4, adj = 0, cex = 0.7)
  # Ajouter des lignes vérticaux
  grid(NA, NULL,
       col = v.couleur[50],
       lwd = 1)
}

# Graphique point + barre d'erreurs
ice_graph <- function(data, titre, ytitre, description){

  MaTitre <- string_wrapper(titre, 50)
  nb_lignes <- sapply(gregexpr("\n", MaTitre), length) - 1
  MyMar <- par()$mar
  MyMar[3] <- MyMar[3] + nb_lignes
  par(mar = MyMar)

  plot <- matplot(x = as.integer(rownames(data)), y = data[,1],
                  xlab = "Années",
                  ylab = ytitre,
                  main = MaTitre,
                  sub = paste("source : ", description), # Titre et texte
                  ylim = c(min(data, na.rm = TRUE),
                           max(data, na.rm = TRUE)), # Limite du graph en y
                  type = "p", # ligne et point
                  pch = 20,# Type de point
                  las = 1, # Orientation texte axes
                  col = v.couleur[1], # Couleur des graphs
                  font.main = 2, font.lab = 3, # Style d'écriture
                  bty = 'l', # Style de cadre de la figure
                  pty = 's' # Figure de forme carré
                  # lab=c(dim(data)[1],5,7) #Combien de graduation en (x,y,7)
  )
  grid(NA, NULL, col = v.couleur[50], lwd = 1)
  segments(as.integer(rownames(data)),
           data[,2],
           as.integer(rownames(data)),
           data[,3],
           col = v.couleur[1])
}

# Graphique en barre
histo <- function(data, titre, xtitre, description){
  # print(data)
  # print(titre)
  par(mar=c(5, 10, 4, 2))

  MaTitre <- string_wrapper(titre, 50)
  nb_lignes <- sapply(gregexpr("\n", MaTitre), length) - 1
  MyMar <- par()$mar
  MyMar[3] <- MyMar[3] + nb_lignes
  par(mar = MyMar)

  MaSub <- string_wrapper(paste0("Source : ", description), 75)
  nb_lignes <- sapply(gregexpr("\n", MaSub), length) - 1
  MyMar <- par()$mar
  MyMar[1] <- MyMar[1] + nb_lignes
  par(mar = MyMar)
  # print(MaSub)

  MaLabels <- string_wrapper(names(data), 20)

  par(mgp = c(2, 1, 0))

  plot <- barplot(data,
                  names.arg = MaLabels,
                  main = MaTitre,
                  # sub = MaSub,
                  xlab = xtitre,
                  horiz = TRUE, #Barplot à l'horizontale
                  las = 1, # Orientation texte axes
                  col = v.couleur[1],
                  border = NA, # Bord des barres
                  cex.names = 1 # Taille texte : label y
  )
  # Ajouter des informations sur les sources
  mtext(text = MaSub, side = 1, line = 4, adj = 0, cex = 0.7)
  # Ajouter des lignes verticaux
  grid(NULL, NA, col = v.couleur[50], lwd = 1)
  # Ajouter les pourcentages (étiquettes)
  text(data / 2, plot, labels = paste(round(data, digits = 2), '%'), pos = 4)
}


# Carte simple
simpleMap <- function(data, titre, description, echelle, classif = FALSE){

  MaTitre <- string_wrapper(titre, 50)
  # print(MaTitre)
  nb_lignes <- sapply(gregexpr("\n", MaTitre), length) - 1
  MyMar <- par()$mar
  MyMar[3] <- MyMar[3] + nb_lignes
  par(mar = MyMar)

  plot <- plot(df.vecteur.reg$geometry[[1]][[1]][[1]],
               xlab = '',
               ylab = '',
               main = MaTitre,
               sub = paste("source : ", description),
               type ='l',
               asp = 1,
               font.main = 2, font.lab = 3, # Style d'écriture
               xaxt = 'n', yaxt = 'n', bty = 'n', # Cache les axes et le cadre
               pin = 5 # Dimension espace plot
               )

  df.dataCarto <- NULL
  unite.legende <- NULL
  if (echelle == 'Région'){
    # print(summary(data$VALEUR))
    data.reg <- data.frame("CENTRE",
                           mean(data$VALEUR[is.finite(data$VALEUR)],
                                na.rm = TRUE),
                           as.character(v.couleur[1]),
                           na.rm = TRUE)
    colnames(data.reg) <- c("IDENTIFIANT","VALEUR","COULEUR")
    df.dataCarto <- merge(df.vecteur.reg,
                          data.reg,
                          by = "IDENTIFIANT",
                          all = TRUE)
    unite.legende <- round(df.dataCarto$VALEUR, 2)
  }
  else if (echelle == 'Département'){
    data.dep <- data.frame()
    for (dep in names(l.lieu$CVL[-1])){
      l.usc <- l.lieu$CVL[[dep]]$data$USC
      val <- mean(data$VALEUR[which(data$IDENTIFIANT %in% l.usc
                                    & is.finite(data$VALEUR))],
                 na.rm = TRUE)
      data.dep <- rbind(data.dep, data.frame(dep, val))
    }
    colnames(data.dep) <- c("IDENTIFIANT","VALEUR")
    # print(data.dep)
    # print(quantile(data.dep$VALEUR))
    # print(is.finite(data.dep$VALEUR))
    df.dataCarto <- merge(df.vecteur.dep, data.dep,
                          by = "IDENTIFIANT",
                          all = TRUE)
    # unite.legende <- round(max(df.dataCarto$VALEUR, na.rm = TRUE) / 5, 2)
    # print(quantile(df.dataCarto$VALEUR[is.finite(df.dataCarto$VALEUR)]))
    legD1 <- quantile(df.dataCarto$VALEUR[df.dataCarto$VALEUR > 0 &
                                                is.finite(df.dataCarto$VALEUR)],
                              probs = 0.05, na.rm = TRUE)
    legQ1 <- quantile(df.dataCarto$VALEUR[df.dataCarto$VALEUR > 0 &
                                                is.finite(df.dataCarto$VALEUR)],
                              probs = 0.25, na.rm = TRUE)
    legM <- quantile(df.dataCarto$VALEUR[df.dataCarto$VALEUR > 0 &
                                                is.finite(df.dataCarto$VALEUR)],
                             probs = 0.5, na.rm = TRUE)
    legQ3 <- quantile(df.dataCarto$VALEUR[df.dataCarto$VALEUR > 0 &
                                                is.finite(df.dataCarto$VALEUR)],
                              probs = 0.75, na.rm = TRUE)
    legD9 <- quantile(df.dataCarto$VALEUR[df.dataCarto$VALEUR > 0 &
                                                is.finite(df.dataCarto$VALEUR)],
                              probs = 0.95, na.rm = TRUE)
    legMax <- max(df.dataCarto$VALEUR[is.finite(df.dataCarto$VALEUR)],
                          na.rm = TRUE)
    # print(paste(unite.legende, max(df.dataCarto$VALEUR), sep = " - "))
    # print(paste(legD1, legQ1, legM, legQ3, legD9, legMax))
    df.dataCarto <- addColorsMap(df.dataCarto, legD1, legQ1, legM, legQ3, legD9)
  }
  else{
    df.dataCarto <- merge(df.vecteur.usc, data, by = "IDENTIFIANT", all = TRUE)
    if(classif == FALSE){
      # unite.legende <- round(max(df.dataCarto$VALEUR, na.rm = TRUE) / 5, 2)
      legD1 <- quantile(df.dataCarto$VALEUR[df.dataCarto$VALEUR > 0 &
                                                is.finite(df.dataCarto$VALEUR)],
                                probs = 0.05, na.rm = TRUE)
      legQ1 <- quantile(df.dataCarto$VALEUR[df.dataCarto$VALEUR > 0 &
                                                is.finite(df.dataCarto$VALEUR)],
                                probs = 0.25, na.rm = TRUE)
      legM <- quantile(df.dataCarto$VALEUR[df.dataCarto$VALEUR > 0 &
                                                is.finite(df.dataCarto$VALEUR)],
                               probs = 0.5, na.rm = TRUE)
      legQ3 <- quantile(df.dataCarto$VALEUR[df.dataCarto$VALEUR > 0 &
                                                is.finite(df.dataCarto$VALEUR)],
                                probs = 0.75, na.rm = TRUE)
      legD9 <- quantile(df.dataCarto$VALEUR[df.dataCarto$VALEUR > 0 &
                                                is.finite(df.dataCarto$VALEUR)],
                                probs = 0.95, na.rm = TRUE)
      legMax <- max(df.dataCarto$VALEUR[is.finite(df.dataCarto$VALEUR)],
                    na.rm = TRUE)
      # print(paste(unite.legende, max(df.dataCarto$VALEUR, na.rm = TRUE), sep = " - "))
      # print(summary(df.dataCarto$VALEUR))
      # print(quantile(df.dataCarto$VALEUR, probls = 0.05, na.rm = TRUE))
      df.dataCarto <- addColorsMap(df.dataCarto,
                                   legD1, legQ1, legM, legQ3, legD9)
    }
  }
  # print(df.dataCarto[which(df.dataCarto$VALEUR >= legQ3),
  #                    c("VALEUR", "COULEUR")])
  for (i in 1:dim(df.dataCarto)[1]){
    # print(class(df.dataCarto$geometry[[i]])[2])
    if(class(df.dataCarto$geometry[[i]])[2] == "MULTIPOLYGON") {
      plot <- polygon(df.dataCarto$geometry[[i]][[1]][[1]],
                      col = df.dataCarto$COULEUR[[i]])
      # print(paste(df.dataCarto$ID[[i]], df.dataCarto$VALEUR[[i]],
      #             df.dataCarto$COULEUR[[i]], sep = " - "))
    } else {
      plot <- polygon(df.dataCarto$geometry[[i]][[1]],
                      col = df.dataCarto$COULEUR[[i]])
      # print(paste(df.dataCarto$ID[[i]], df.dataCarto$VALEUR[[i]],
      #             df.dataCarto$COULEUR[[i]], sep = " - "))
    }
  }

  if(classif == FALSE){
    if(echelle == 'Région'){
      legende <- c(paste("=", unite.legende), "0", "NA")
      palette <- c(v.couleur[1])
      couleur <- c(palette, "#FFFFFF",
                   v.couleur[50])
    } else{
      # val.legend <- lapply(unite.legende, '*', 5:1)
      # legende <- c(paste('>', val.legend[[1]]),
                   # paste('< ', val.legend[[1]][-1]),
                   #"0", "NA")
      legLL <- formatC(c(legD9, legQ3, legM, legQ1, legD1, 0),
                       digits = 2, format = "fg", flag = "#")
      legUL <- formatC(c(legMax, legD9, legQ3, legM, legQ1, legD1),
                       digits = 2, format = "fg", flag = "#")
      legende <- c("Infini", paste0("(", legLL, ",", legUL, "]"),
                   "0", "NA")
      palette <- c(v.couleur[8],
                   v.couleur[7],
                   v.couleur[6],
                   v.couleur[5],
                   v.couleur[45],
                   v.couleur[46])
      couleur <- c("#000000",
                   palette[1:(length(legende)-3)],
                   "#FFFFFF",
                   v.couleur[50])
    }
    plot <- legend('topleft', legend = legende, fill = couleur, bty = "n")
  }
}


#---------- AFFICHAGE ET EXPORT DES GRAPHS ----------

plotExportUI <- function(id) {
  ns <- NS(id)
  tagList(
    splitLayout(
      plotOutput(ns("preview1")),
      plotOutput(ns("preview2"))
    ),
    splitLayout(
      textAreaInput(ns("preview1leg"),
                    label = "Légende (graph 1) :",
                    width = "100%",
                    rows = 3,
                    resize = "horizontal"),
      textAreaInput(ns("preview2leg"),
                    label = "Légende (graph 2) :",
                    width = "100%",
                    rows = 3)
    ),
    splitLayout(
      plotOutput(ns("preview3")),
      plotOutput(ns("preview4"))
    ),
    splitLayout(
      textAreaInput(ns("preview3leg"),
                    label = "Légende (graph 3) :",
                    width = "100%",
                    rows = 3),
      textAreaInput(ns("preview4leg"),
                    label = "Légende (graph 4) :",
                    width = "100%",
                    rows = 3)
    ),
    tags$hr(),
    tags$p("ATTENTION : Avant de télécharger vos résultats, merci de vérifier
           que les 4 espaces de graphiques sont utilisés."),
    textInput(ns("titrerapport"),
              label = "Titre :",
              width = "800px"),
    textAreaInput(ns("commentaire"),
                  label = "Veuillez décrire l'objectif et le contenu de votre rapport :",
                  width = "800px",
                  rows = 6),
    textAreaInput(ns("auteur"),
                  label = "Auteur(s) :",
                  width = "100%",
                  rows = 3),
    downloadButton(ns("download"), "Téléchargement")
  )
}

plotExport <- function(input, output, session,
                       data.graph1, data.graph2, data.graph3, data.graph4) {

  output$preview1 <- renderPlot({
    validate(
      need(!is.null(data.graph1$data),
           "Cet espace de graphique est vide. Veuillez sélectionner vos
           variables et cliquer sur le bouton adapté.")
      %then% need(!is.character(data.graph1$data), data.graph1$data)
      )
    plotType(data.graph1$data,
             data.graph1$representation,
             data.graph1$graphTitre,
             data.graph1$yTitre,
             data.graph1$source,
             data.graph1$echelle)
  })

  output$preview2 <- renderPlot({
    validate(
      need(!is.null(data.graph2$data),
           "Cet espace de graphique est vide. Veuillez sélectionner vos
           variables et cliquer sur le bouton adapté.")
      %then% need(!is.character(data.graph2$data), data.graph2$data)
    )
    plotType(data.graph2$data,
             data.graph2$representation,
             data.graph2$graphTitre,
             data.graph2$yTitre,
             data.graph2$source,
             data.graph2$echelle)
  })

  output$preview3 <- renderPlot({
    validate(
      need(!is.null(data.graph3$data),
           "Cet espace de graphique est vide. Veuillez sélectionner vos
           variables et cliquer sur le bouton adapté.")
      %then% need(!is.character(data.graph3$data), data.graph3$data)
    )
    plotType(data.graph3$data,
             data.graph3$representation,
             data.graph3$graphTitre,
             data.graph3$yTitre,
             data.graph3$source,
             data.graph3$echelle)
  })

  output$preview4 <- renderPlot({
    validate(
      need(!is.null(data.graph4$data),
           "Cet espace de graphique est vide. Veuillez sélectionner vos
           variables et cliquer sur le bouton adapté.")
      %then% need(!is.character(data.graph4$data),data.graph4$data)
    )
    plotType(data.graph4$data,
             data.graph4$representation,
             data.graph4$graphTitre,
             data.graph4$yTitre,
             data.graph4$source,
             data.graph4$echelle)
  })

  output$download <- downloadHandler(
    filename = paste0("Reforest",
                      Sys.Date(),"_",
                      round(runif(1, min = 1000, max = 9999)),
                      ".pdf"),
    content = function(file) {
      src <- normalizePath("rapportVisu.Rmd")
      src2 <- normalizePath("www/Bandeau_logos_edited.jpg")

      # Temporarily switch to the temp dir, in case you do not have write
      # permission to the current working directory
      owd <- setwd(tempdir())
      on.exit(setwd(owd))
      file.copy(src, "rapportVisu.Rmd", overwrite = TRUE)
      file.copy(src2, "Bandeau_logos_edited.jpg")

      # Set up parameters to pass to Rmd document
      # print(data.graph2$graphTitre)
      MesParams <- list(reporttitle = input$titrerapport,
                        comments = input$commentaire,
                        authors = input$auteur,
                        legend1 = input$preview1leg,
                        legend2 = input$preview2leg,
                        legend3 = input$preview3leg,
                        legend4 = input$preview4leg,
                        graph1.data = data.graph1$data,
                        graph1.representation = data.graph1$representation,
                        graph1.titre = data.graph1$graphTitre,
                        graph1.yTitre = data.graph1$yTitre,
                        graph1.source = data.graph1$source,
                        graph1.echelle = data.graph1$echelle,
                        graph2.data = data.graph2$data,
                        graph2.representation = data.graph2$representation,
                        graph2.titre = data.graph2$graphTitre,
                        graph2.yTitre = data.graph2$yTitre,
                        graph2.source = data.graph2$source,
                        graph2.echelle = data.graph2$echelle,
                        graph3.data = data.graph3$data,
                        graph3.representation = data.graph3$representation,
                        graph3.titre = data.graph3$graphTitre,
                        graph3.yTitre = data.graph3$yTitre,
                        graph3.source = data.graph3$source,
                        graph3.echelle = data.graph3$echelle,
                        graph4.data = data.graph4$data,
                        graph4.representation = data.graph4$representation,
                        graph4.titre = data.graph4$graphTitre,
                        graph4.yTitre = data.graph4$yTitre,
                        graph4.source = data.graph4$source,
                        graph4.echelle = data.graph4$echelle)

      visuRapport <- rmarkdown::render("rapportVisu.Rmd", params = MesParams)
      file.rename(visuRapport, file)
    }
  )
}


#---------- AFFICHAGE ET EXPORT DES CARTES INTERACTIVES ----------

mapExportUI <- function(id) {
  ns <- NS(id)
  tagList(
    leafletOutput(ns("MyMap"), height = "640px"),
    textInput(ns("titrerapportcarto"),
              label = "Titre :",
              width = "800px"),
    textAreaInput(ns("commentairecarto"),
                  label = "Veuillez décrire l'objectif et le contenu de votre rapport :",
                  width = "800px",
                  rows = 6),
    textAreaInput(ns("auteurcarto"),
                  label = "Auteur(s) :",
                  width = "100%",
                  rows = 3),
    downloadButton(ns("mapdownload"), "Téléchargement")
  )
}

mapExport <- function(input, output, session, data.carte, parametre.carte) {

  # La partie statique de la carte
  output$MyMap <- renderLeaflet({
    # MyMap <- leaflet(options = leafletOptions(crs = epsg2154))
    MyMap <- leaflet(options = leafletOptions(zoomSnap = 0.25,
                                              zoomDelta = 0.25))

    # Les cartes de fond
    MyMap <- addTiles(map = MyMap,
                      'http://{s}.tile.openstreetmap.org/{z}/{x}/{y}.png',
                      group = "OpenStreetMap")
    MyMap <- addPolygons(map = MyMap, data = df.vecteur.reg4326,
                         fill = TRUE, color = "#000000",
                         fillColor = "lightgray",
                         opacity = 1, group = "Région",
                         weight = 2)
    MyMap <- addPolygons(map = MyMap, data = df.vecteur.dep4326,
                         fill = FALSE, color = "#000000",
                         opacity = 1, group = "Département",
                         weight = 2)
    MyMap <- addPolygons(map = MyMap, data = df.vecteur.usc4326,
                         fill = FALSE, color = "#000000",
                         opacity = 1, group = "Unité de gestion",
                         weight = 1)
    MyMap <- addLayersControl(map = MyMap,
      baseGroups = c("OpenStreetMap", "Région"),
      overlayGroups = c("Département", "Unité de gestion"),
      options = layersControlOptions(collapsed = FALSE))
    MyMap <- hideGroup(map = MyMap,
                       group = "Unité de gestion")

    return(MyMap)
  })

  # La partie dynamique de la carte
  # La carte dynamique

  observe({

    if(isTruthy(parametre.carte$echelle) == FALSE) {
      # print(isTruthy(parametre.carte$echelle))
      leafletProxy(map = "MyMap") %>%
        clearGroup(group = "MyCircles") %>%
        clearGroup(group = "MyPolygons")
    } else if(isTruthy(parametre.carte$echelle) == TRUE) {
      # print(isTruthy(parametre.carte$echelle))
      # print(isTruthy(data.carte$data))
      # req(data.carte$data)
      # print(parametre.carte$echelle)
      if(parametre.carte$echelle == "Département") {
        if(parametre.carte$affichagegeo == "Centroïdes") {
          df.dataCarte <- merge(df.vecteur.dep4326.centroids,
                                data.carte$data,
                                by = "IDENTIFIANT", all = TRUE)
        } else {
          df.dataCarte <- merge(df.vecteur.dep4326,
                                data.carte$data,
                                by = "IDENTIFIANT", all = TRUE)
        }
      } else {
        if(parametre.carte$affichagegeo == "Centroïdes") {
          df.dataCarte <- merge(df.vecteur.usc4326.centroids,
                                data.carte$data,
                                by = "IDENTIFIANT", all = TRUE)
        } else {
          df.dataCarte <- merge(df.vecteur.usc4326,
                                data.carte$data,
                                by = "IDENTIFIANT", all = TRUE)
        }
      }

      # LesCouleurs
      # print(max(abs(df.dataCarte$VALEUR[is.finite(df.dataCarte$VALEUR)]),
      #           na.rm = TRUE))
      if(parametre.carte$indicateurgeo == "Indicateur standardisé"){
        ColorRange <-
          -ceiling(max(abs(df.dataCarte$VALEUR[is.finite(df.dataCarte$VALEUR)]),
               na.rm = TRUE)) :
          ceiling(max(abs(df.dataCarte$VALEUR[is.finite(df.dataCarte$VALEUR)]),
              na.rm = TRUE))
        # print(ColorRange)
        LesCouleurs <- colorNumeric(
          palette = "RdBu",
          domain = ColorRange,
          na.color="#808080")
      } else {
        LesCouleurs <- colorNumeric(
          palette = "viridis",
          domain = df.dataCarte$VALEUR[is.finite(df.dataCarte$VALEUR)])
      }


      if(parametre.carte$echelle == "Département") {
          LesRayons <- 25000
      } else {
        LesRayons <- 2500
      }
      # print(length(LesCouleurs(df.dataCarte$VALEUR)))
      # print(parametre.carte$affichagegeo)
      if(parametre.carte$affichagegeo == "Centroïdes"){
        leafletProxy(map = "MyMap") %>%
          clearGroup(group = "MyCircles") %>%
          clearGroup(group = "MyPolygons") %>%
          addCircles(data = df.dataCarte[is.finite(df.dataCarte$VALEUR), ],
                     group = "MyCircles",
                     color = ~LesCouleurs(
                       df.dataCarte$VALEUR[is.finite(df.dataCarte$VALEUR)]),
                     fill = TRUE,
                     fillOpacity = 0.85,
                     radius = LesRayons,
                     weight = 1)
      } else {
        leafletProxy(map = "MyMap") %>%
          clearGroup(group = "MyCircles") %>%
          clearGroup(group = "MyPolygons") %>%
          addPolygons(data = df.dataCarte[is.finite(df.dataCarte$VALEUR), ],
                      group = "MyPolygons",
                      strok = FALSE,
                      color = ~LesCouleurs(
                        df.dataCarte$VALEUR[is.finite(df.dataCarte$VALEUR)]),
                      fill = TRUE,
                      fillOpacity = 0.85,
                      weight = 1)
      }
    }
  })


  # La légende dynamique
  observe({

    if(isTruthy(parametre.carte$echelle) == FALSE) {
      # print(isTruthy(parametre.carte$echelle))
      leafletProxy(map = "MyMap") %>%
        removeControl(layerId = "MyColorLeg")
    } else if(isTruthy(parametre.carte$echelle) == TRUE) {
      if(parametre.carte$echelle == "Département") {
        df.dataCarte <- merge(df.vecteur.dep4326.centroids,
                              data.carte$data,
                              by = "IDENTIFIANT", all = TRUE)
      } else {
        df.dataCarte <- merge(df.vecteur.usc4326.centroids,
                              data.carte$data,
                              by = "IDENTIFIANT", all = TRUE)
      }

      # LesCouleurs
      if(parametre.carte$indicateurgeo == "Indicateur standardisé"){
        ColorRange <-
          -ceiling(max(abs(df.dataCarte$VALEUR[is.finite(df.dataCarte$VALEUR)]),
               na.rm = TRUE)) :
          ceiling(max(abs(df.dataCarte$VALEUR[is.finite(df.dataCarte$VALEUR)]),
              na.rm = TRUE))
        LesCouleurs <- colorNumeric(
          palette = "RdBu",
          domain = ColorRange,
          na.color="#808080")
      } else {
        LesCouleurs <- colorNumeric(
          palette = "viridis",
          domain = df.dataCarte$VALEUR[is.finite(df.dataCarte$VALEUR)])
      }

      if(parametre.carte$donnees == "Cynégétique") {
        MyLegendTitle <- as.character(
          string_wrapper_html(
            paste(
              parametre.carte$indicateur,
              parametre.carte$individu,
              parametre.carte$tableau,
              sep = " | "), 15))
      } else {
        MyLegendTitle <- as.character(
          string_wrapper_html(
            paste(
              parametre.carte$indicateur,
              parametre.carte$tableau,
              sep = " | "), 15))
      }
      leafletProxy(map = "MyMap") %>%
        removeControl(layerId = "MyColorLeg") %>%
        addLegend(data = df.dataCarte[is.finite(df.dataCarte$VALEUR), ],
                  position = "bottomright",
                  layerId = "MyColorLeg",
                  title = MyLegendTitle,
                  # title = parametre.carte$indicateur,
                  pal = LesCouleurs,
                  bins = 5,
                  values = ~df.dataCarte$VALEUR[is.finite(df.dataCarte$VALEUR)]
        )
    }
  })

  # map download parameters
  # mapdownload <- reactive({
  #   # specify coordinates (and zoom level) for current view
  #   mapboundaries <- input$map_bounds
  #   latitudinalRng <- range(mapboundaries$north, mapboundaries$south)
  #   longitudinalRng <- range(mapboundaries$east, mapboundaries$west)
  #   output$MyMap %>% setView(lng = (longitudinalRng[1]+longitudinalRng[2])/2,
  #                       lat = (latitudinalRng[1]+latitudinalRng[2])/2,
  #                       zoom = input$map_zoom)
  # })

  output$mapdownload <- downloadHandler(
    filename = paste0("Reforest",
                      Sys.Date(),"_",
                      round(runif(1, min = 1000, max = 9999)),
                      ".pdf"),
    content = function(file) {
      src <- normalizePath("rapportCarto.Rmd")
      src2 <- normalizePath("www/Bandeau_logos_edited.jpg")

      # Temporarily switch to the temp dir, in case you do not have write
      # permission to the current working directory
      owd <- setwd(tempdir())
      on.exit(setwd(owd))
      file.copy(src, "rapportCarto.Rmd", overwrite = TRUE)
      file.copy(src2, "Bandeau_logos_edited.jpg")

      # Set up parameters to pass to Rmd document
      # print(input$MyMap_bounds)
      print(reactiveValuesToList(input))
      MesMapParams <- list(mapreporttitle = input$titrerapportcarto,
                        mapcomments = input$commentairecarto,
                        mapauthors = input$auteurcarto,
                        mapdata = data.carte$data,
                        maptarget = parametre.carte$cible,
                        mapscale = parametre.carte$echelle,
                        mapboundaries = input$MyMap_bounds,
                        mapindicatortype = parametre.carte$indicateurgeo,
                        mapfeature = parametre.carte$affichagegeo,
                        mapdatatype = parametre.carte$donnees,
                        mapindicator = parametre.carte$indicateur,
                        mapanimal = parametre.carte$individu,
                        mapindicatorcat = parametre.carte$tableau,
                        dfvecteurreg4326 = df.vecteur.reg4326,
                        dfvecteurdep4326 = df.vecteur.dep4326,
                        dfvecteurusc4326 = df.vecteur.usc4326,
                        dfvecteurdep4326centroids = df.vecteur.dep4326.centroids,
                        dfvecteurusc4326centroids = df.vecteur.usc4326.centroids,
                        mapgroups = input$MyMap_groups
                        )

      cartoRapport <- rmarkdown::render("rapportCarto.Rmd",
                                        params = MesMapParams)
      file.rename(cartoRapport, file)
    }
  )
}


#---------- MAIN ----------

graphic <- function(input, output, session, dataset,
                    indicateur, echelle, lieu, espece, annee){

  toReturn <- reactiveValues(
    data = NULL,
    representation = NULL,
    graphTitre = NULL,
    yTitre = "Ratio (sans unité)",
    source = NULL,
    echelle = NULL
  )

  observe({

    typeGraph <- subset(df.ind,
                        INDICATEUR == indicateur(),
                        select = REPRESENTATION)
    # print(indicateur())
    # print(typeGraph)

    validate(
      need(!is.na(typeGraph), "Cet indicateur n'est pas encore implémenté.")
    )

    if (typeGraph == "graph") {
      if (dataset() == "Sylvicole"){
        toReturn$data <- dataprocess_sylv(indicateur(),
                                          echelle(),
                                          lieu())
        toReturn$representation <- "simple"
        toReturn$graphTitre <- paste(indicateur(),
                                     'en',
                                     lieu())
      } else if (dataset() == "ICE"){
        toReturn$data <- dataprocess_ice(indicateur(),
                                         espece(),
                                         echelle(),
                                         lieu())
        toReturn$representation <- "ice"
        toReturn$graphTitre <- paste(indicateur(),'de',
                                     espece(),
                                     'en',
                                     lieu())
      } else{
        # print("test")
        toReturn$data <- dataprocess_cyn(indicateur(),
                                         echelle() ,
                                         lieu() ,
                                         espece())
        toReturn$representation <- "simple"
        toReturn$graphTitre <- paste(indicateur(),
                                     'de',
                                     espece(),
                                     'en',
                                     lieu())
      }
    } else if(subset(df.ind, INDICATEUR == indicateur(),
                    select = REPRESENTATION) == "histogramme"){
      # print(indicateur())
      toReturn$data <- dataprocess_barplot(indicateur(),
                                           echelle(),
                                           lieu(),
                                           annee())
      toReturn$representation <- "histo"
      toReturn$graphTitre <- paste(indicateur(),
                                   'en',
                                   lieu())
    } else{
      toReturn$data <- dataprocess_map(indicateur(),
                                       espece(),
                                       annee())
      toReturn$representation <- "carte"
      toReturn$echelle <- echelle()
      toReturn$graphTitre <- paste(indicateur(),
                                   'de', annee(),
                                   "chez le",
                                   espece())
    }
    if (!is.na(subset(df.ind,
                      INDICATEUR==indicateur(),
                      select = UNITE_ABR))){
      # print(indicateur())
      toReturn$yTitre <- subset(df.ind,
                                INDICATEUR == indicateur(),
                                select = UNITE_ABR)
    }
    toReturn$source <- subset(df.ind,
                              INDICATEUR == indicateur(),
                              select = SOURCE)


    # validate( need(!any(is.infinite(toReturn$data)),
    # "Pas de données de cerf disponible pour cette unité de gestion.") )
    # validate( need(!all(is.na(toReturn$data)),
    # "Pas de données disponible pour cette unité de gestion.") )
  })

  return(toReturn)
}


#---------- CARTE INTERACTIVE ----------

carteinteractive <- function(input, output, session, dataset, tableau,
                             indicateurgeo, cible, indicateur,
                             espece, annee, echelle) {

  toReturn <- reactiveValues(
    data = NULL
  )

  observe({
    req(dataset())

    # print(paste(indicateur(), espece(), echelle(), annee(), sep = " - "))
    # print(indicateurgeo())
    # print(tableau())
    if (dataset() == "Sylvicole") {
      toReturn$data <- dataprocess_mapdyn(dataset(),
                                          tableau = tableau(),
                                          indicateurgeo(),
                                          cible(),
                                          indicateur(),
                                          espece = NULL,
                                          annee(),
                                          echelle())
    } else if (dataset() == "ICE") {
      toReturn$data <- dataprocess_ice(indicateur(),
                                       espece(),
                                       echelle(),
                                       annee())
    } else {
      toReturn$data <- dataprocess_mapdyn(dataset(),
                                          tableau(),
                                          indicateurgeo(),
                                          cible(),
                                          indicateur(),
                                          espece(),
                                          annee(),
                                          echelle())
    }
  })

  return(toReturn)
}
