#### MODULE DE MENU DE SELECTION DE L'APPLICATION REFOREST ####

### INRAE : Projet ReForest : Création d'un démonstrateur
### Auteur : DUMBO Marie
### Date : 18/06/2020
### Mise-à-jours : cf. Git history for successive modifications by MÅRELL Anders

#---------- Choix du lieu ----------

selectLocationUI <- function(id){
  ns <- NS(id)
  if(id == "carto"){
    l.echelle <- c("Département", "Unité de gestion")
    selectInput(ns("sel.echelle"),
                label = "Emprise spatiale :",
                choices = l.echelle)
  } else {
    l.echelle <- c("Région", "Département", "Unité de gestion")
    tagList(
      if(id != "tendance"){
        selectInput(ns("sel.echelle"),
                    label = "Emprise spatiale :",
                    choices = l.echelle)
        },
      selectInput(ns("sel.lieu"), label = NULL, choices = NULL)
    )
  }
}

selectLocation <- function(input, output, session, dataset = NULL){
  toReturn <- reactiveValues(
    echelle = NULL,
    lieu = NULL
  )
  observe({
    choix <- dimnames(a.ice)$ID
    if(!is.null(input$sel.echelle)){
      if (input$sel.echelle == "Région"){
        choix <- c(names(l.lieu))
      } else if (input$sel.echelle == "Département"){
        choix <- names(l.lieu$CVL)[-1]
      } else if (input$sel.echelle == "Unité de gestion") {
        if(dataset() == "Cynégétique"){
          choix <- dimnames(a.pdc)$ID
        } else if(dataset() == "ICE"){
          choix <- dimnames(a.ice)$ID
        } else{
          choix <- dimnames(a.sylv)$ID
        }
      }
    }
    if(is.null(dataset)) {
      updateSelectInput(session, "sel.lieu",
                        label = "Unité de gestion :",
                        choices = choix)
    } else {
      updateSelectInput(session, "sel.lieu",
                        label = paste0(input$sel.echelle, " :"),
                        choices = choix)
    }
  })

  observe({
    toReturn$echelle <- input$sel.echelle
    toReturn$lieu <- input$sel.lieu
  })

  return(toReturn)
}

#---------- Création des boutton de création de graphique ----------

buttonGraphUI <- function (id){
  ns <- NS(id)
  tagList(
    tags$h3("Veuillez choisir votre espace de création de graphique :"),
    tags$div( style = "margin-left: auto;
    margin-right: auto; width: 50%",
      actionButton(ns("plot1"),"Espace 1"),
      actionButton(ns("plot2"),"Espace 2"),tags$br(),
      actionButton(ns("plot3"),"Espace 3"),
      actionButton(ns("plot4"),"Espace 4")
             )
  )
}

buttonGraph1 <- function(input, output, session){
  toReturn <- reactiveValues(
    lieu = NULL,
    annee = NULL,
    individu = NULL,
    indicateur = NULL,
    echelle = NULL,
    donnees = NULL
  )
  observeEvent(input$plot1,{
    toReturn$lieu <- input$sel.lieu
    toReturn$annee <- input$annee
    toReturn$indicateur <- input$indicateur
    toReturn$donnees <- input$data
    toReturn$echelle <- input$sel.echelle
    toReturn$individu <- input$espece
  })
  return(toReturn)
}

buttonGraph2 <- function(input, output, session){
  toReturn <- reactiveValues(
    lieu = NULL,
    annee = NULL,
    echelle = NULL,
    indicateur = NULL,
    individu = NULL,
    donnees = NULL
  )
  observeEvent(input$plot2,{
    toReturn$lieu <- input$sel.lieu
    toReturn$donnees <- input$data
    toReturn$individu <- input$espece
    toReturn$annee <- input$annee
    toReturn$echelle <- input$sel.echelle
    toReturn$indicateur <- input$indicateur
  })
  return(toReturn)
}

buttonGraph3 <- function(input, output, session){
  toReturn <- reactiveValues(
    lieu = NULL,
    echelle = NULL,
    individu = NULL,
    annee = NULL,
    donnees = NULL,
    indicateur = NULL
  )
  observeEvent(input$plot3,{
    toReturn$echelle <- input$sel.echelle
    toReturn$individu <- input$espece
    toReturn$lieu <- input$sel.lieu
    toReturn$donnees <- input$data
    toReturn$annee <- input$annee
    toReturn$indicateur <- input$indicateur
  })
  return(toReturn)
}

buttonGraph4 <- function(input, output, session){
  toReturn <- reactiveValues(
    lieu = NULL,
    echelle = NULL,
    individu = NULL,
    donnees = NULL,
    annee = NULL,
    indicateur = NULL
  )
  observeEvent(input$plot4,{
    toReturn$echelle <- input$sel.echelle
    toReturn$individu <- input$espece
    toReturn$lieu <- input$sel.lieu
    toReturn$donnees <- input$data
    toReturn$annee <- input$annee
    toReturn$indicateur <- input$indicateur
  })
  return(toReturn)
}


#---------- Création de boutton de création de carte interactive ----------

buttonCarteUI <- function (id){
  ns <- NS(id)
  tagList(
    actionButton(ns("carte"), "Visualiser"),
    actionButton(ns("carteReset"), "Réinitialiser")
  )
}

buttonCarte <- function(input, output, session) {
  toReturn <- reactiveValues(
    annee = NULL,
    individu = NULL,
    indicateur = NULL,
    echelle =NULL,
    donnees = NULL,
    tableau = NULL,
    affichagegeo = NULL,
    indicateurgeo = NULL,
    cible = NULL
  )
  observeEvent(input$carte, {
    toReturn$annee <- input$annee
    toReturn$indicateur <- input$indicateur
    toReturn$donnees <- input$data
    toReturn$tableau <- input$tableau
    toReturn$indicateurgeo <- input$indicateurgeo
    toReturn$cible <- input$norme
    toReturn$echelle <- input$sel.echelle
    toReturn$individu <- input$espece
    toReturn$affichagegeo <- input$affichagegeo
    # print(toReturn$echelle)
  })

  observeEvent(input$carteReset, {
    # print("test")
    toReturn$annee <- NULL
    toReturn$indicateur <- NULL
    toReturn$donnees <- NULL
    toReturn$tableau <- NULL
    toReturn$indicateurgeo <- NULL
    toReturn$cible <- NULL
    toReturn$echelle <- NULL
    toReturn$individu <- NULL
    toReturn$affichagegeo <- NULL
    # print(toReturn$donnes)
    # print(toReturn$echelle)
  })

  # print(toReturn)
  return(toReturn)
}

#---------- Création des bouttons de lancement de classification ----------

buttonClassifUI <- function(id){
  ns <- NS(id)
  tagList(
    actionButton(ns("bouton.classif"),"Lancer la classification")
  )
}

buttonClassif <- function(input, output, session){
  toReturn <- reactiveValues(
    annee= NULL,
    donnee = NULL,
    k=NULL
  )
  observeEvent(input$bouton.classif,{
    toReturn$annee <- input$annee
    toReturn$donnee <- input$data
    toReturn$k <- input$cluster
  })
  return(toReturn)
}


#---------- Choix du nombre de cluster ----------

enterClusterUI <- function (id){
  ns <- NS(id)
  tagList(
    numericInput(ns("cluster"),
                 label = "Nombre de groupe : (50 max)",
                 min = 2,
                 max = 50,
                 value = NULL )
  )
}

enterCluster <- function(input, output, session, data){
  observe({
    k = NULL
    if(data() == "Cynégétique"){
      k <- classif.pdc.k
    } else if (data() == "Sylvicole"){
      k <- classifSylv.k
    } else {
      k <-  classif.k
    }
    updateNumericInput(session, "cluster", value = k)
  })
  reactive({input$cluster})
}

#---------- Création des bouttons de lancement d'analyse ----------

buttonLauchUI <- function(id){
  ns <- NS(id)
  tagList(
    actionButton(ns("bouton.tendance"), "Analyse")
  )
}

buttonLauch <- function(input, output, session) {
  toReturn <- reactiveValues(
    lieu = NULL,
    indicateur = NULL,
    individu = NULL
  )

  observeEvent(input$bouton.tendance, {
    toReturn$lieu <- input$sel.lieu
    toReturn$indicateur <- input$indicateur
    toReturn$individu <- input$espece
  })
  return(toReturn)
}


#---------- Création des bouttons de téléchargement ----------

buttonDownloadUI <- function(id){
  ns <- NS(id)
  tagList(
    downloadButton(ns('bout.telecharge'), 'Télécharger')
  )
}


#---------- Choix de l'année ----------

#####
# sliderYearUI <- function(id){
#   ns <- NS(id)
#   lab <- NULL
#   anneePDCsylv <- as.integer(intersect(dimnames(a.pdc)$ANNEE,
#                                        dimnames(a.sylv)$ANNEE))
#   if (id == "visu"){
#     lab <- "Année :"
#   } else if(id == "carto") {
#     lab <- "Année :"
#   } else{
#     lab <- "L'analyse est réalisée sur 3 années, choisissez la première :"
#   }
#   tagList(
#     sliderInput(ns("annee"),
#                 label = lab,
#                 value = anneePDCsylv[length(anneePDCsylv)] -2,
#                 min = anneePDCsylv[1],
#                 max = anneePDCsylv[length(anneePDCsylv)] -2,
#                 sep = "",
#                 step = 1)
#   )
# }
#
#as.integer(min(dimnames(a.pdc)$ANNEE, dimnames(a.sylv)$ANNEE ))
#
# sliderYear <- function(input, output, session, dataset = NULL){
#   observe({
#     data <- NULL
#     if (!is.null(dataset)){
#       if(dataset() == "Cynégétique"){data = a.pdc}
#       else if (dataset() == "ICE"){data = a.ice}
#       else {data = a.sylv}
#       updateSliderInput(session, "annee",
#                         value = max(dimnames(data)$ANNEE),
#                         min = min(dimnames(data)$ANNEE),
#                         max = max(dimnames(data)$ANNEE))
#     }
#   })
#   reactive({input$annee})
# }

#####
selectYearUI <- function(id) {
  ns <- NS(id)
  lab <- NULL

  MyYears <- as.integer(intersect(dimnames(a.pdc)$ANNEE,
                                       dimnames(a.sylv)$ANNEE))
  # Label conditional on tabview
  if (id == "visu") {
    lab <- "Année :"
  } else if(id == "carto") {
    lab <- "Année :"
  } else {
    lab <- "L'analyse est réalisée sur 3 années, choisissez la première :"
  }
  tagList(
    selectInput(ns("annee"),
                label = lab,
                choices = c(MyYears))
  )
}

selectYear <- function(input, output, session, parent_session,
                       dataset = NULL, indicator = NULL) {

  # Years conditional on dataset and indicator
  observe({
    # print(dataset)
    data <- NULL
    if (!is.null(dataset)) {
      if(dataset() == "Cynégétique") {data = a.pdc}
      else if(dataset() == "ICE") {data = a.ice}
      else {
        data <- a.sylv
        if(!is.null(indicator)) {
          if(indicator() == "Taux de boisement") {
            MyIndicator <- "Structure foncière de la forêt"
          } else {
            MyIndicator <- grep(sub(" \\(.*", "", indicator()),
                                dimnames(a.sylv)$INDICATEUR, value = TRUE)
          }
          # Test data for all NA per year (dimension 2)
          # print(parent_session$input$navbar)
          # print(MyIndicator)
          # print(input$tableau)
          if(parent_session$input$navbar == "Cartographie") {
            if(identical(MyIndicator, character(0)) == FALSE) {
              if(MyIndicator[1] == "Peuplements sensibles") {
                # print(paste("Branche1", MyIndicator, sep = " - "))
                if(input$tableau ==
                   "Taux d'interventions sylvicoles par télédétection" |
                   input$tableau ==
                   "Taux de peuplements en phase de renouvellement (HT<3m, forêts publiques)" |
                   input$tableau ==
                   "Taux de peuplements en phase de renouvellement (HT>3m, forêts publiques)") {
                  # print(input$tableau)
                  tableau <- input$tableau
                  tableau <- sub("Taux", "Surface", tableau)
                  MyYears <- apply(data[, , MyIndicator, tableau, ], c(2),
                                   function(x) all(is.na(x)))
                  MyYears <- names(
                    MyYears[MyYears == FALSE]) # Keep years with data
                  data <- a.sylv[, MyYears, MyIndicator, tableau, "VALEUR", drop = FALSE]
                }
              } else {
                # print(paste("Branche2", MyIndicator, sep = " - "))
                MyYears <- apply(data[, , MyIndicator, , ], c(2),
                                 function(x) all(is.na(x)))
                MyYears <- names(
                  MyYears[MyYears == FALSE]) # Keep years with data
                data <- a.sylv[, MyYears, MyIndicator, , "VALEUR", drop = FALSE]
              }
            }
          } else {
            # print(paste("Branche3", MyIndicator, sep = " - "))
            # print(dimnames(data))
            MyYears <- apply(data[, , MyIndicator, ,], c(2),
                             function(x) all(is.na(x)))
            MyYears <- names(MyYears[MyYears == FALSE]) # Keep years with data
            data <- a.sylv[, MyYears, MyIndicator, , "VALEUR", drop = FALSE]
          }
        }
      }
      # print(dimnames(data)$ANNEE)
      updateSelectInput(
        session, "annee",
        choices = c(sort(dimnames(data)$ANNEE, decreasing = TRUE)))
    }
  })

  reactive({input$annee})
}
#---------- Choix de l'indicateur ----------

selectIndicateurUI <- function(id) {
  ns <- NS(id)
  tagList(
    selectInput(ns("indicateur"),
                label = "Indicateur :",
                choices = NULL)
  )
}

selectIndicateur <- function(input, output, session, parent_session,
                             dataset = NULL, lieu = NULL) {
  observe({
    # print(parent_session$input$navbar)
    choix <- NULL
    if(is.null(dataset)) {
      if(nchar(lieu()) > 0) {
        check1 <- apply(a.ice[lieu(), , , , "avg"], MARGIN = c(2, 3), is.na)
        check2 <- apply(check1, MARGIN = c(2, 3), all)
        check3 <- apply(check2, MARGIN = c(2), all)
        choix <- c(unique(names(check3[check3 == FALSE])))
        rm(check1, check2, check3)
        # choix <- c(subset(df.ind, TYPE == "ICE", select = "INDICATEUR"))
      } else {
        choix <- c(subset(df.ind, TYPE == "ICE", select = "INDICATEUR"))
      }
    } else if(dataset() == "Cynégétique") {
      # Distinguish between Visu and Carto tab (PDC with or without Attr/Real)
      if(parent_session$input$navbar == "Visualisation") {
        choix <- c(subset(df.ind, TYPE == "Cynégétique", select = "INDICATEUR"))
        # print(parent_session$input$navbar)
      } else if(parent_session$input$navbar == "Cartographie") {
        choix <- c(subset(df.ind, TYPE == "Cynégétique", select = "INDICATEUR"))
        choix <- vapply(strsplit(choix$INDICATEUR," - ", fixed = TRUE),
                        "[", 1, FUN.VALUE = character(1))
        # print(choix)
      }
    } else if(dataset() == "Sylvicole") {
      # Distinguish between Visu and Carto tab
      if(parent_session$input$navbar == "Visualisation") {
        choix <- c(subset(df.ind, TYPE == "Sylvicole", select = "INDICATEUR"))
      } else if(parent_session$input$navbar == "Cartographie") {
        choix <- c(subset(df.ind, TYPE == "Sylvicole", select = "INDICATEUR"))
        # print(choix)
        choix$INDICATEUR[grepl("Notation 'Gibier' de l'ONF", choix$INDICATEUR)] <-
          "Notation 'Gibier' de l'ONF"
        choix$INDICATEUR[grepl("Notation 'Gibier' du CRPF", choix$INDICATEUR)] <-
          "Notation 'Gibier' du CRPF"
        choix$INDICATEUR <- unique(choix$INDICATEUR)
        # print(choix)
      }
    } else {
      choix <- c(subset(df.ind, TYPE == dataset(), select = "INDICATEUR"))
    }
    updateSelectInput(session, "indicateur", choices = choix)
  })
  reactive({input$indicateur})
}


#---------- Choix de l'espèce ----------

selectIndivUI <- function(id){
  ns <- NS(id)
  tagList(
    # Seulement pour les données cynégétique et ICE
    conditionalPanel(
      condition = "input.data == 'Cynégétique'||input.data == 'ICE'",
      ns = ns,
      selectInput(ns("espece"), label = NULL, choices = NULL)
    )
  )
}

selectIndiv <- function(input, output, session, ind = NULL){
  observe({
    choix.esp <- l.animal
    lab = "Espéce : "
    if(is.null(ind)) {
      choix.esp <- c("Total", "Cerf", "Chevreuil")
    } else {
      # print(ind())
      if(ind() != "") {
        # print(ind() == "Structure foncière de la forêt")
        if(ind() == "Plan de Chasse aux 100 ha" |
           ind() == "Plan de Chasse aux 100 ha boisés") {
          choix.esp$Chevreuil$Jeune <- NULL
        } else if(ind() == "Structure foncière de la forêt" |
                  ind() == "Notation 'Gibier' de l'ONF" |
                  ind() == "Notation 'Gibier' du CRPF") {
          choix.esp <- ""
        } else if(subset(df.ind,
                  INDICATEUR == ind(),
                  select = TYPE) == "Sylvicole") {
          choix.esp <- ""
        } else if(subset(df.ind,
                        INDICATEUR == ind(),
                        select = TYPE) == "ICE") {
          lab <- "Catégorie d'animal :"
          if(ind() == 'Masse Corporelle des jeunes (MC)') {
            choix.esp <- l.animal$Chevreuil[2] # Jeune
          } else {
            choix.esp <- l.animal$Chevreuil[1] # Total
          }
        } else if(subset(df.ind,
                        INDICATEUR == ind(),
                        select = REPRESENTATION) == "graph"){
          choix.esp <- "Cerf"
        } else {
          choix.esp$Chevreuil$Jeune <- NULL
        }
      }
    }
    # print(choix.esp)
    updateSelectInput(session, "espece",
                      label = lab,
                      choices = choix.esp)
  })
  reactive({input$espece})
}


#---------- Choix de l'ensemble de données ----------


selectDatasetUI <- function(id){
  ns <- NS(id)
  if(id == "classif" | id == "rapport"){
    tagList(
      radioButtons(ns("data"),
                   label = "Type de données :",
                   choices = c('Total', 'Cynégétique', 'Sylvicole'))
    )
  } else{
    tagList(
      radioButtons(ns("data"),
                   label = "Type de données :",
                   choices = levels(df.ind$TYPE))
    )
  }
}

selectDataset <- function(input, output, session){
  reactive({
    # print(input$data)
    input$data
  })
}


#---------- Choix de l'indicateur spécifique pour la carte interactive ----------

# Conditional panels
selectTableauUI <- function(id) {
  ns <- NS(id)
  tagList(
    uiOutput(ns("tableauCond"))
  )
}

selectTableau <- function(input, output, session,
                          dataset, indicateur) {

  output$tableauCond <- renderUI({
    ns <- session$ns
    if(dataset() == "Cynégétique") {
      MyCondition <- "input.data == 'Cynégétique'"
      MyLabel <- "Attributions / Réalisations :"
      MyChoices <- c("Attributions", "Réalisations")
      MyChoice <- "Réalisations"
    } else if(indicateur() == "Taux de boisement") {
      MyCondition <- "input.indicateur ==
        'Taux de boisement'"
      MyLabel <- "Quel attribut de l'indicateur ?"
      MyChoices <- c("Taux de forêts",
                     "Taux d'autres occupations du sol")
      MyChoice <- "Taux de forêts"
    } else if(indicateur() == "Peuplements sensibles") {
      MyCondition <- "input.indicateur ==
        'Peuplements sensibles'"
      MyLabel <- "Quel attribut de l'indicateur ?"
      MyChoices <-
        c("Taux d'interventions sylvicoles par télédétection",
          "Taux de peuplements en phase de renouvellement (HT<3m, forêts publiques)",
          "Taux de peuplements en phase de renouvellement (HT>3m, forêts publiques)")
      MyChoice <- "Taux d'interventions sylvicoles par télédétection"
    } else if(indicateur() == "Structure foncière de la forêt (Surface totale)") {
      MyCondition <- "input.indicateur ==
        'Structure foncière de la forêt (Surface totale)'"
      MyLabel <- "Quel attribut de l'indicateur ?"
      MyChoices <- c("Taux de forêts publiques",
                     "Taux de forêts privées sans DGD",
                     "Taux de forêt privée soumise à un document de gestion",
                     "Taux d'autres occupations du sol")
      MyChoice <- "Taux de forêts publiques"
    } else if(indicateur() == "Structure foncière de la forêt (Surface forestière)") {
      MyCondition <- "input.indicateur ==
        'Structure foncière de la forêt (Surface forestière)'"
      MyLabel <- "Quel attribut de l'indicateur ?"
      MyChoices <- c("Taux de forêts publiques",
                     "Taux de forêts privées sans DGD",
                     "Taux de forêt privée soumise à un document de gestion")
      MyChoice <- "Taux de forêts publiques"
    } else if(indicateur() == "Composition en essences") {
      MyCondition <- "input.indicateur ==
        'Composition en essences'"
      MyLabel <- "Quel attribut de l'indicateur ?"
      MyChoices <- c("Taux de forêts de feuillus",
                     "Taux de forêts mélangées",
                     "Taux de forêts de résineux")
      MyChoice <- "Taux de forêts de feuillus"
    } else if(indicateur() == "Notation 'Gibier' de l'ONF") {
      MyCondition <- "input.indicateur ==
        'Notation 'Gibier' de l'ONF"
      MyLabel <- "Quel attribut de l'indicateur ?"
      MyChoices <- c("Peuplements HT<3m (forêts publiques)",
                     "Peuplements HT>3m (forêts publiques)")
      MyChoice <- "Peuplements HT<3m (forêts publiques)"
    } else if(indicateur() == "Notation 'Gibier' du CRPF") {
      MyCondition <- "input.indicateur ==
        'Notation 'Gibier' du CRPF"
      MyLabel <- "Quel attribut de l'indicateur ?"
      MyChoices <- c("Abroutissement sur les essences 'objectif'",
                     "Abroutissement sur la végétation d'accompagnement",
                     "Ecorçage sur les essences 'objectif'")
      MyChoice <- "Abroutissement sur les essences 'objectif'"
    } else {
      MyCondition <- NULL
    }
    req(MyCondition)
    conditionalPanel(
      condition = MyCondition,
      ns = ns,
      selectInput(ns("tableau"),
                  label = MyLabel,
                  choices = MyChoices,
                  selected = MyChoice)
    )
  })
}

#---------- Choix de l'affichage des données géographiques ----------

selectAffichageUI <- function(id){
  ns <- NS(id)
  tagList(
    radioButtons(ns("affichagegeo"),
                 label = "Forme d'affichage :",
                 choices = c("Centroïdes", "Polygones"))
  )
}

#---------- Choix du type d'indicateur ----------

selectTypeIndicateurUI <- function(id){
  ns <- NS(id)
  tagList(
    radioButtons(ns("indicateurgeo"),
                 label = "Type d'indicateur :",
                 choices = c("Indicateur non corrigé",
                             "Indicateur standardisé")
    )
  )
}

# selectTypeIndicateur <- function(input, output, session){
#   reactive({input$indicateurgeo})
# }

#---------- Valeur de référence pour l'indicateur standardisé ----------

selectNormeUI <- function(id){
  ns <- NS(id)
  tagList(
    # Seulement pour l'indicateur standardisé
    conditionalPanel(
      condition = "input.indicateurgeo == 'Indicateur standardisé'",
      ns = ns,
      numericInput(ns("norme"),
                   label = "Préciser l'objectif de gestion (la valeur cible) :",
                   value = NULL)
    ),
    tags$p(
      tags$em("L'indicateur standardisé permet de visualiser l'indicateur
              par rapport à un objectif de gestion (la valeur cible) :")),
    tags$li(
      tags$em("les valeurs négatives, en rouges, sont inférieures à la
              cible ;")),
    tags$li(
      tags$em("les valeurs positives, en bleues, sont supérieures à la cible."))
  )
}

#---------- MAIN ----------

sidebarUI <- function(id){
  if (id == "visu"){
    tagList(
      wellPanel(
        tags$h2("Paramétrage des données :"),
        tags$hr(),
        selectDatasetUI(id),
        selectIndicateurUI(id),
        selectLocationUI(id),
        selectYearUI(id),
        selectIndivUI(id),
        buttonGraphUI(id))
    )
  } else if (id == "carto"){
    tagList(
      wellPanel(
        tags$h2("Paramétrage des données :"),
        tags$hr(),
        selectDatasetUI(id),
        selectIndicateurUI(id),
        selectTableauUI(id),
        selectLocationUI(id),
        selectIndivUI(id),
        selectYearUI(id))
      )
  } else if (id == "classif") {
    tagList(
      sidebarPanel(tags$h2("Veuillez sélectionner les paramètres souhaités :"),
                   tags$hr(),
                   selectDatasetUI(id),
                   selectYearUI(id),
                   enterClusterUI(id),
                   buttonClassifUI(id))
    )
  } else if (id == "tendance"){
    tagList(
      sidebarPanel(tags$h2("Veuillez sélectionner les paramètres souhaités :"),
                   tags$hr(),
                   selectLocationUI(id),
                   selectIndicateurUI(id) ,
                   selectIndivUI(id),
                   buttonLauchUI(id))
    )
  }else if (id == "risque"){
    tagList(
      sidebarPanel(selectYearUI(id))
    )
  }else{
    tagList(
      tags$div(
        column(id= "menu-rapport",
               width = 6,offset = 3,
                tags$h2("Veuillez sélectionner les paramètres souhaités : "),
               tags$hr(),
                selectDatasetUI(id),
               selectLocationUI(id),
               selectIndivUI(id)
        )
      )
    )
  }
}

sidebarUI2 <- function(id){
  if (id == "carto"){
    tagList(
      wellPanel(tags$h2("Paramétrage de l'affichage :"),
                tags$hr(),
                selectAffichageUI(id),
                selectTypeIndicateurUI(id),
                selectNormeUI(id),
                tags$br(),
                buttonCarteUI(id))
    )
  }
}
