#### MODULE STATISTIQUE DE L'APPLICATION REFOREST ####

### INRAE : Projet ReForest : Création d'un démonstrateur
### Auteur : DUMBO Marie
### Date : 23/06/2020
### Mise-à-jours : cf. Git history for successive modifications by MÅRELL Anders


#---------- CLASSIFICATION ----------

# Préparation des données
dataprocess_classif <- function(dataset, annee){
  data.sylv <- NULL
  data.cyn <- NULL
  data <- NULL
  annee3 <- dimnames(a.sylv)$ANNEE[(
    which(dimnames(a.sylv)$ANNEE == annee)):
      (which(dimnames(a.sylv)$ANNEE == annee) + 2)]
  if (dataset == 'Sylvicole' | dataset == 'Total'){
    data.sylv <- a.sylv[,annee3,c(classif.varSylv)]
    data.sylv <- apply(data.sylv, c(1,3), mean,na.rm=TRUE)
    if (dataset == 'Sylvicole'){
      return(data.sylv)
    }
  }
  if (dataset == 'Cynégétique' | dataset == 'Total'){
    data.cyn <- a.pdc[,annee3,,]
    data.cyn[is.na(data.cyn)] <- 0
    categorie <- dimnames(data.cyn)$CATEGORIE
    data.cyn.att <- apply(data.cyn[,,,1], c(1,3), mean, na.rm=TRUE)
    dimnames(data.cyn.att)$CATEGORIE <- paste(categorie,
                                              rep("att", length(categorie)),
                                              sep = ".")
    data.cyn.rea <- apply(data.cyn[,,,2], c(1,3), mean, na.rm=TRUE)
    dimnames(data.cyn.rea)$CATEGORIE <- paste(categorie,
                                              rep("rea",
                                                  length(categorie)),
                                              sep = ".")
    data.cyn <- merge(data.cyn.att,data.cyn.rea, by = "row.names")
    rownames(data.cyn) <- data.cyn$Row.names
    data.cyn <- data.cyn[,-1]
    data.cyn <- as.matrix(data.cyn)
    data.cyn <- data.cyn[,c(classif.varPDC)]
    if (dataset == 'Cynégétique'){
      return(data.cyn)
    }
  }
  if (dataset =='Total'){
    data <- merge(data.sylv,data.cyn, by="row.names")
    rownames(data) <- data$Row.names
    data <- data[,-1]
    data <- as.matrix(data)
  }
}

# Mise en forme du tableau de resultat
maketable <- function(data){
  data.factor <- as.factor(data)
  names(data.factor) <- sapply(names(data.factor),
                               function(x) substr(x,2,nchar(x)))
  aggreg.res <- aggregate(names(data.factor),
                          list(data.factor),
                          paste,
                          collapse =' - ')
  df.res <- aggreg.res[2]
  rownames(df.res) <- paste('Cluster', 1:dim(df.res)[1])
  df.res
}

# Lengende de classification
legend.mapClassif <- function(k){
  min=0
  max=k*2
  plot(NA,
       type = "n",
       ann = FALSE,
       xlim = c(min, max),
       ylim = c(min, max),
       xaxt = 'n',
       yaxt = 'n',
       bty = "n")
  rect(xleft = seq(min, max - 1, 2),
       ybottom = max-2,
       xright = seq(min + 1, max, 2),
       ytop = max,
       col = v.couleur[1:k])
  mtext("Legende cluster :", 3)
  text(seq(0.5, max - 0.5, 2), max - 4, 1:k, cex = 0.55)
}


# MAIN
# enterVoirCluster <- function(input, output, session, data){
#   observe({
#     k <- input$cluster
#     updateNumericInput(session, "voirCluster", max = k)
#   })
# }

clusteringUI <- function(id){
  ns <- NS(id)
  # maxK <- 10
  # print(maxK)
  tagList(
    mainPanel(
      tabsetPanel(
        tabPanel("Carte",
                 plotOutput(ns("carte.res")),
                 plotOutput(ns("legend.carte"))),
        tabPanel( "Tableau de résultat",
                  tableOutput(ns('df.res'))),
        tabPanel("Résultats graphiques",
                 numericInput(ns("voirCluster"),
                              label = "Choississez un cluster à mettre en
                              évidence :",
                              min = 1,
                              max = 50,
                              value = 1),
                 plotOutput(ns("plot.res")),
                 tags$p("Cette espace vous permet d'interperter les résultats
                        de la classification en regardant, pour un groupe donné,
                        quels sont les variables pour lesquels il est normals,
                        élevés, extremement faible etc, comme le montre la
                        figure ci-dessous"),
                 tags$div(img(src="boxplot.png")))
        ),
      textInput(ns("commentaire.clust"), label = "Voulez-vous ajouter un
                commentaire à votre analyse ?"),
      downloadButton(ns("download.clust"), "Téléchargement")
    )
  )
}


clustering <- function(input, output, session, dataset, annee, k){
  observe({
    validate(need(!is.null(dataset()),
                  "Veuillez selectionnez vos variables et lancer l'analyse") )

    data <- dataprocess_classif(dataset(), annee())
    data <- scale(data)
    data <- t(data)
    kmeans.res <- kmeansvar(X.quanti = data,
                            init = k(),
                            iter.max = 300,
                            nstart = classif.nstart,
                            matsim = FALSE)
    id <- sapply(names(kmeans.res$cluster), function(x) substr(x, 2, nchar(x)))
    id <- sapply(id, function(x) gsub('.','-',x, fixed = TRUE))
    df.cluster <- data.frame(id, kmeans.res$cluster, NA)
    colnames(df.cluster) <- c("IDENTIFIANT","VALEUR", "COULEUR")
    for ( clust in 1:k()){
      df.cluster[which(df.cluster$VALEUR == clust),
                 "COULEUR"] <- v.couleur[clust]
    }
    df.resultat <- maketable(kmeans.res[["cluster"]])

    output$df.res <- renderTable({
      df.resultat
    },
    rownames = TRUE, colnames = FALSE, bordered = TRUE
    )

    updateNumericInput(session, "voirCluster", value = 1, max = k())

    output$plot.res <- renderPlot({
      m.score <- t(kmeans.res$score)
      boxplot(m.score)
      points(m.score[paste0("cluster",
                            ifelse(input$voirCluster > k(),
                                   1,
                                   input$voirCluster)),],
             col = v.couleur[1],
             pch = 19,
             cex = 1.5)
    })

    output$carte.res <- renderPlot({
      simpleMap(df.cluster,
                paste("Carte de classification des unités de gestion en",
                      annee()),
                "Calcul réalisé grâce au package ClustOfVar sur l'ensemble des
                données disponibles dans ce tableau de bord",
                "Unité de gestion", classif = TRUE)
    })

    output$legend.carte <- renderPlot({
      legend.mapClassif(k())
    })


    output$download.clust <- downloadHandler(
      filename = paste0("Reforest-classification",
                        Sys.Date(),"_",
                        round(runif(1, min = 1000, max = 9999)),
                        ".pdf"),
      content = function(file){
        pdf(file)
        par(mfrow = c(1,1))
        grid.table(df.resultat)
        par(mfrow = c(2, 1))
        simpleMap(df.cluster, paste("Carte de classification des unités de
                                    gestion en",
                                    annee()),
                  "Calcul réalisé grâce au package ClustOfVar sur l'ensemble
                  des données disponibles dans ce tableau de bord",
                  "Unité de gestion",
                  classif = TRUE)
        legend.mapClassif(k())
        if(input$commentaire.clust != ""){
          mtext(input$commentaire.clust,  side=1, outer = TRUE, line=2)
        }
        dev.off()
      }
    )
  })
}

#---------- RISQUE ----------


#---------- TENDANCE ----------

trendUI <- function(id){
  ns <- NS(id)
  tagList(
    mainPanel(
      plotOutput(ns("plot.tendence")),
      tableOutput(ns("table.tendance")),
      textInput(ns("commentaire.tendance"),
                label = "Voulez-vous ajouter un commentaire à votre analyse ?"),
      downloadButton(ns("download.tendance"), "Téléchargement")
    )
  )
}


trend <- function(input, output, session, indicateur, lieu, espece ){
  observe({

    if(!is.null(indicateur())){
      data <- a.ice[lieu(), , espece(), indicateur(), ]
      i.na <- which(apply(data,1, function(x) all(is.na(x))))
      if(length(i.na) != 0){
        data <- data[-c(i.na),]
      }

      if(dim(data)[1]!=0){
        start.year <- min(as.integer(row.names(data)))
        end.year <- max(as.integer(row.names(data)))
        time.serie <- ts(data = data[,'corr'],
                         frequency=1,
                         start = start.year,
                         end = end.year )

        l <- length(time.serie)
        tt <- 1:l # Time serie
        # Breakpoint analysis with a minimum of 4 years for a segment
        brkpt <- strucchange::breakpoints(time.serie ~ tt, h = 4)

        brkpt.years <- strucchange::breakdates(brkpt)
        nb.brkpt <- length(brkpt$breakpoints)
        start.years <- c(start.year, brkpt.years + 1)
        end.years <- c(brkpt.years, end.year)

        seg <- mapply(function(x,y) x:y, start.years, end.years)

        ts.window <- function(y,z) window(time.serie, start = y, end = z)
        brkpt.ts <- mapply(ts.window, start.years, end.years)
        lmH0.ts <- function(x) lm(x ~ 1)
        lmH1.ts <- function(x, y) lm(x ~ y)
        fm.H0 <- lapply(brkpt.ts, lmH0.ts)
        fm.H1 <- mapply(lmH1.ts, brkpt.ts, seg, SIMPLIFY = FALSE)

        aov.fit<-mapply(anova, fm.H0, fm.H1, SIMPLIFY = FALSE) # Model selection
        p.fit <- lapply(aov.fit, function(x)x$"Pr(>F)"[2]) # Extract p-values

        fit.H0<-lapply(fm.H0, fitted)
        fit.H1<-lapply(fm.H1, fitted) # Fitted values

        cond <- lapply(p.fit, function(x) x <= 0.05) # TRUE for H1
        fit <- fit.H0
        fit[cond == TRUE] <- fit.H1[cond == TRUE]

        # Extract coefficients
        coef.H0 <- lapply(fm.H1, function(x) x$coefficients)
        coef.H1 <- lapply(fm.H1, function(x) x$coefficients)

        coeffs <- coef.H0
        coeffs[cond == TRUE] <- coef.H1[cond == TRUE]
      }
    }

    output$plot.tendence <- renderPlot({
      validate(
        need(!is.null(lieu()),
             message = "Veuillez lancer une analyse")
        %then% need(dim(data)[1] != 0,
                    message = "Désolé, il n'y a pas de données disponibles pour
                    ces parametres")
      )

      data[,c(2,3)] <- NA
      plot.titre <- paste("Tendance de l'",
                          indicateur(), "chez le",
                          espece(),
                          "en",
                          lieu())
      if(indicateur() == "Masse Corporelle des jeunes (MC)"){
        plot.titre <- paste("Tendance de la",
                            indicateur(),
                            "chez le",
                            espece(),
                            "en",
                            lieu())
      }
      plot <- ice_graph(data[,1:3], titre = plot.titre,
                        ytitre = subset(df.ind,
                                        INDICATEUR == indicateur(),
                                        select = UNITE_ABR),
                        description = subset(df.ind,
                                             INDICATEUR == indicateur(),
                                             select = SOURCE))
      mapply(function(x,y) lines(x, y, col= v.couleur[2], lwd = 3 ), seg, fit)
    })

    t <- NULL
    output$table.tendance <- renderTable({
      validate(
        need(!is.null(lieu()), message = "")
        %then% need(dim(data)[1]!=0, message = "")
      )

      seg.v <- unlist(lapply(seg,function(x) paste(min(x), max(x), sep =" - ")))
      p.fit.v <- formatC(signif(unlist(p.fit), digits = 2),
                       digits = 2,
                       format = "fg",
                       flag = "#")
      a <- formatC(signif(unlist(lapply(coeffs,function(x) x[1])), digits = 4),
                   digits = 4,
                   format = "fg",
                   flag = "#")
      b <- formatC(signif(unlist(lapply(coeffs,function(x) x[2])), digits = 4),
                   digits = 4,
                   format = "fg",
                   flag = "#")
      t <- data.frame(Période = seg.v,
                      Ordonnée = as.numeric(a),
                      Pente  = as.numeric(b),
                      P.value = as.numeric(p.fit.v))
      t$Tendance[t$P.value > 0.05] <- "Stable"
      t$Tendance[t$P.value <= 0.05 & t$Pente < 0] <- "A la baisse"
      t$Tendance[t$P.value <= 0.05 & t$Pente > 0] <- "A la hausse"
      t
    })

    output$download.tendance <- downloadHandler(
      filename = paste0("Reforest-tendence",
                        Sys.Date(),"_",
                        round(runif(1, min = 1000, max = 9999)),
                        ".pdf"),
      content = function(file){
        pdf(file)
        par(mfrow = c(1,1))
        plot(NA,
             type = "n",
             ann = FALSE,
             xlim = c(0,1),
             ylim = c(0, 1),
             xaxt = 'n',
             yaxt = 'n',
             bty = "n")
        mtext(paste("Résultat de l'analyse des tendances :
                    Réalisée sur le tableau de bord ReForest le",
                    Sys.Date()),
              side = 3)
        seg.v <- unlist(lapply(seg, function(x)
          paste(min(x), max(x), sep = " - ")))
        p.fit.v <- formatC(signif(unlist(p.fit), digits = 2),
                           digits = 2,
                           format = "fg",
                           flag = "#")
        a <- formatC(signif(unlist(lapply(coeffs, function(x) x[1])),
                            digits = 4),
                     digits = 4,
                     format = "fg",
                     flag = "#")
        b <- formatC(signif(unlist(lapply(coeffs, function(x) x[2])),
                            digits = 4),
                     digits = 4,
                     format = "fg",
                     flag = "#")
        t <- data.frame(Période = seg.v,
                        Ordonnée = as.numeric(a),
                        Pente = as.numeric(b),
                        P.value = as.numeric(p.fit.v))
        t$Tendance[t$P.value > 0.05] <- "Stable"
        t$Tendance[t$P.value <= 0.05 & t$Pente < 0] <- "A la baisse"
        t$Tendance[t$P.value <= 0.05 & t$Pente > 0] <- "A la hausse"
        grid.table(t)
        par(mfrow = c(1, 1))
        par(oma = c(0, 0, 3, 0))
        data[,c(2, 3)] <- NA
        plot.titre <- paste("Tendance de l'",
                            indicateur(),
                            "chez le",
                            espece(),
                            "en",
                            lieu())
        if(indicateur() == "Masse Corporelle des jeunes (MC)"){
          plot.titre <- paste("Tendance de la",
                              indicateur(),
                              "chez le",
                              espece(),
                              "en",
                              lieu())
        }
        plot <- ice_graph(data[, 1:3], titre = plot.titre,
                          ytitre = subset(df.ind,
                                          INDICATEUR == indicateur(),
                                          select = UNITE_ABR),
                          description = subset(df.ind,
                                               INDICATEUR == indicateur(),
                                               select = SOURCE))
        mapply(function(x,y) lines(x, y, col = v.couleur[2], lwd = 3), seg, fit)
        if(input$commentaire.tendance != ""){
          mtext(input$commentaire.tendance,  side = 1, outer = TRUE, line = 2)
        }
        dev.off()
      }
    )


  })
}



